'use strict';

var paladin = require('@pld/paladin');
var paladin$1 = require('@pld/paladin');

var HLLUMethod;
(function (HLLUMethod) {
    HLLUMethod["getUserInfo"] = "get_user_info";
    HLLUMethod["personalCenter"] = "personal_center";
    HLLUMethod["getShareOrderEntranceRedDot"] = "share_order_entrance_red_dot";
    HLLUMethod["customSetReadDot"] = "custom_set_read_dot";
    HLLUMethod["personalCenterGuidePop"] = "personal_center_guide_pop";
})(HLLUMethod || (HLLUMethod = {}));

class HLLUSensorControl {
    constructor() {
        this.sensorDict = {};
    }
    static getInstance() {
        let instance = HLLUSensorControl.instance;
        if (!instance) {
            instance = new HLLUSensorControl();
            HLLUSensorControl.instance = instance;
        }
        return instance;
    }
}

class HLLUBridge {
    static sendMessage(context, bridgeModule, methodName, param) {
        param.success = (result) => {
            if (param.successCallback) {
                param.successCallback(result);
            }
        };
        // 用于网络请求
        param.fail = (err) => {
            if (param.failureCallback) {
                param.failureCallback(err);
            }
        };
        context.sendMessage(bridgeModule, methodName, param);
    }
    // 埋点交互
    static sendTrackSensorEvent(params) {
        if (params.needControl) {
            // 控制曝光埋点次数
            if (params.specialSensor) {
                let hasSensored = HLLUSensorControl.getInstance().sensorDict[params.specialSensor];
                if (hasSensored) {
                    return;
                }
                HLLUSensorControl.getInstance().sensorDict[params.specialSensor] = true;
            }
            let hasSensored = HLLUSensorControl.getInstance().sensorDict[JSON.stringify(params.properties)];
            if (hasSensored) {
                return;
            }
            HLLUSensorControl.getInstance().sensorDict[JSON.stringify(params.properties)] = true;
        }
        this.sendMessage(context, 'hllUTrack', "tracWithParams", params);
    }
    // 网络请求
    static sendNetRequestEvent(type, method, params, successCallback = null, failureCallback = null) {
        this.sendMessage(context, "network", "request", {
            method: type,
            params: {
                args: Object.assign({}, params),
                method
            },
            successCallback,
            failureCallback
        });
    }
    // 用户基本信息
    static collectUserBaseInfo(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'HLLUUserBaseInfoBridge', methodName, params);
    }
    // 个人中心业务交互
    static sendPersonalCenterNativeEvent(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'HLLUPersonalCenterBridge', methodName, params);
    }
    // 基本能力桥接
    static sendCommonNativeEvent(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'HLLUCommonBridge', methodName, params);
    }
    // 原生modal交互
    static sendModalNativeEvent(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'modal', methodName, params);
    }
    static sendNavigatorNativeEvent(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'navigator', methodName, params);
    }
}

var HLLUUserBaseInfoBridge;
(function (HLLUUserBaseInfoBridge) {
    HLLUUserBaseInfoBridge["getCityInfo"] = "getCityInfo";
    HLLUUserBaseInfoBridge["getLoginInfo"] = "getLoginInfo";
    HLLUUserBaseInfoBridge["getUserPhone"] = "getUserPhone";
    HLLUUserBaseInfoBridge["getHomepageChangeModeCount"] = "getHomepageChangeModeCount";
    HLLUUserBaseInfoBridge["getMDAPConfigForStringValue"] = "getMDAPConfigForStringValue";
    HLLUUserBaseInfoBridge["getUserFid"] = "getUserFid";
    HLLUUserBaseInfoBridge["getUserToken"] = "getUserToken";
})(HLLUUserBaseInfoBridge || (HLLUUserBaseInfoBridge = {}));
var HLLUPersonalCenterEventBridge;
(function (HLLUPersonalCenterEventBridge) {
    HLLUPersonalCenterEventBridge["checkIfShowSettingRedDot"] = "checkIfShowSettingRedDot";
    HLLUPersonalCenterEventBridge["clickSettingEvent"] = "clickSettingEvent";
    HLLUPersonalCenterEventBridge["getRecommendSwitch"] = "getRecommendSwitch";
    HLLUPersonalCenterEventBridge["sendUserInfoData"] = "sendUserInfoData";
    HLLUPersonalCenterEventBridge["clickAvatarOrLoginEvent"] = "clickAvatarOrLoginEvent";
    HLLUPersonalCenterEventBridge["clickUserOrderCompleteEvent"] = "clickUserOrderCompleteEvent";
    HLLUPersonalCenterEventBridge["clickStarRatingEvent"] = "clickStarRatingEvent";
    HLLUPersonalCenterEventBridge["clickEnterpriseAuthEvent"] = "clickEnterpriseAuthEvent";
    HLLUPersonalCenterEventBridge["getUnreadMessageCount"] = "getUnreadMessageCount";
    HLLUPersonalCenterEventBridge["getLastEnterShareOrderTimestamp"] = "getLastEnterShareOrderTimestamp";
    HLLUPersonalCenterEventBridge["clickPersonalEntranceCommonEvent"] = "clickPersonalEntranceCommonEvent";
    HLLUPersonalCenterEventBridge["setLastEnterShareOrderTimestamp"] = "setLastEnterShareOrderTimestamp";
    HLLUPersonalCenterEventBridge["reportAdvertiseSensor"] = "reportAdvertiseSensor";
    HLLUPersonalCenterEventBridge["openMoreServicePageEvent"] = "openMoreServicePageEvent";
    HLLUPersonalCenterEventBridge["getMoreServiceData"] = "getMoreServiceData";
    HLLUPersonalCenterEventBridge["openWalletyPageEvent"] = "openWalletyPageEvent";
    HLLUPersonalCenterEventBridge["openCouponPageEvent"] = "openCouponPageEvent";
    HLLUPersonalCenterEventBridge["getGuideCanShow"] = "getGuideCanShow";
    HLLUPersonalCenterEventBridge["saveGuideShowTime"] = "saveGuideShowTime";
    HLLUPersonalCenterEventBridge["openAddressUploadPageEvent"] = "openAddressUploadPageEvent"; // 打开地址上报页面事件
})(HLLUPersonalCenterEventBridge || (HLLUPersonalCenterEventBridge = {}));
var HLLUCommonEventBridge;
(function (HLLUCommonEventBridge) {
    // 1.页面返回
    HLLUCommonEventBridge["pageGoBack"] = "pageGoBack";
    // 2.展示吐司
    HLLUCommonEventBridge["showToast"] = "showToast";
    HLLUCommonEventBridge["openLoginPageEvent"] = "openLoginPageEvent";
    HLLUCommonEventBridge["openScanPageEvent"] = "openScanPageEvent";
    HLLUCommonEventBridge["openARPageEvent"] = "openARPageEvent";
    HLLUCommonEventBridge["getDeviceInfo"] = "getDeviceInfo"; // 获取设备信息
})(HLLUCommonEventBridge || (HLLUCommonEventBridge = {}));
var HLLUModalEventBridge;
(function (HLLUModalEventBridge) {
    // 1.展示Loading
    HLLUModalEventBridge["showLoading"] = "showLoading";
    // 2.隐藏Loading
    HLLUModalEventBridge["dismissLoading"] = "dismissLoading";
})(HLLUModalEventBridge || (HLLUModalEventBridge = {}));
var HLLUBroadCastEvent;
(function (HLLUBroadCastEvent) {
    // 1.监听登录成功的通知
    HLLUBroadCastEvent["kNotificationLogin"] = "kNotificationLogin";
    // 2.监听退出登录的通知
    HLLUBroadCastEvent["kNotificationLogout"] = "kNotificationLogout";
    // 3.展示加载中的Lottie动画
    HLLUBroadCastEvent["showLoadingLottieAniamtion"] = "kNotificationshowLoadingLottieAniamtion";
    // 4.隐藏Lottie动画
    HLLUBroadCastEvent["hideLoadingLottieAniamtion"] = "kNotificationHideLoadingLottieAniamtion";
    // 5.监听用户昵称修改的通知
    HLLUBroadCastEvent["kNotificationChangeUserNickName"] = "kNotificationChangeUserNickName";
    // 6.刷新设置红点
    HLLUBroadCastEvent["kRefreshSettingRetDot"] = "kRefreshSettingRetDot";
})(HLLUBroadCastEvent || (HLLUBroadCastEvent = {}));
var HLLUNavigatorEventBridge;
(function (HLLUNavigatorEventBridge) {
    HLLUNavigatorEventBridge["setBarHidden"] = "setBarHidden";
})(HLLUNavigatorEventBridge || (HLLUNavigatorEventBridge = {}));

var HLLHTTPMethod;
(function (HLLHTTPMethod) {
    HLLHTTPMethod["GET"] = "GET";
    HLLHTTPMethod["POST"] = "POST";
})(HLLHTTPMethod || (HLLHTTPMethod = {}));
/**
 * 请求端上接口
 * @param method 接口名
 * @param params 接口参数
 * @param succuss 请求成功回调
 * @param failure 请求失败回调
*/
function fetch(parameter, succuss = null, failure = null, type = HLLHTTPMethod.GET) {
    if (parameter.showloading) {
        HLLUBridge.sendModalNativeEvent(HLLUModalEventBridge.showLoading);
    }
    HLLUBridge.sendNetRequestEvent(type, parameter.method, parameter.params, (response) => {
        if (parameter.showloading) {
            HLLUBridge.sendModalNativeEvent(HLLUModalEventBridge.dismissLoading);
        }
        if (succuss) {
            succuss(response);
        }
    }, (err) => {
        if (parameter.showloading) {
            HLLUBridge.sendModalNativeEvent(HLLUModalEventBridge.dismissLoading);
        }
        if (failure) {
            failure(err);
        }
    });
}

class HLLUTools {
    /**
    * 判断字符串是否为JSON字符串
    */
    static isValidJsonString(str) {
        if (typeof str !== 'string') {
            return false;
        }
        try {
            const parsed = JSON.parse(str);
            return parsed && typeof parsed === 'object';
        }
        catch (e) {
            return false;
        }
    }
    /**
     * 判断对象的key是否为空
     * @param obj
     * @param key
     * @returns {boolean}
     */
    static isEmpty(obj, key) {
        if (!this.contain(obj, key)) {
            return true;
        }
        if (obj[key].length > 0) {
            return false;
        }
        return true;
    }
    /**
     * 判断对象是否包含key
     * @param {Object} obj
     * @param {string} key
     * @returns {boolean}
     */
    static contain(obj, key) {
        if (!this.isObject(obj)) {
            return false;
        }
        if (Object.prototype.toString.call(obj[key]) === '[object Undefined]') {
            return false;
        }
        return true;
    }
    /**
     * 判断是否数组
     * @param val
     * @returns {boolean}
     */
    static isArray(val) {
        if (Object.prototype.toString.call(val) === '[object Array]') {
            return true;
        }
        return false;
    }
    /**
     * 判断是否字符串
     * @param val
     * @returns {boolean}
     */
    static isString(val) {
        if (Object.prototype.toString.call(val) === '[object String]') {
            return true;
        }
        return false;
    }
    /**
     * 判断是否数字[注意，NaN也为数字]
     * @param val
     * @returns {boolean}
     */
    static isNumber(val) {
        if (Object.prototype.toString.call(val) === '[object Number]') {
            return true;
        }
        return false;
    }
    /**
     * 判断是否boolean类型
     * @param val
     * @returns {boolean}
     */
    static isBoolean(val) {
        if (Object.prototype.toString.call(val) === '[object Boolean]') {
            return true;
        }
        return false;
    }
    static isFunction(val) {
        if (Object.prototype.toString.call(val) === '[object Function]') {
            return true;
        }
        return false;
    }
    /**
     * 判断是否对象
     * @param val
     * @returns {boolean}
     */
    static isObject(val) {
        if (Object.prototype.toString.call(val) === '[object Object]') {
            return true;
        }
        return false;
    }
    static getRandomColor() {
        var letters = '0123456789ABCDEF';
        var color = '#';
        for (var i = 0; i < 6; i++) {
            color += letters[Math.floor(Math.random() * 16)];
        }
        return color;
    }
    static $string(value) {
        if (typeof value == 'undefined' || value === null) {
            return "";
        }
        return value.toString();
    }
    static $number(value) {
        value = Number(value);
        if ((value + '') == 'NaN') {
            return 0;
        }
        return value;
    }
    static $money(value) {
        value = Number(value);
        if ((value + '') == 'NaN') {
            return "";
        }
        value = value / 100;
        let formatted = value.toFixed(2);
        formatted = formatted.replace(/\.0+$/, "");
        formatted = formatted.replace(/(\.\d+?)0+$/, "$1");
        return formatted;
    }
    static formatDateToChinese(dateStr) {
        try {
            const yearMonthDayPattern = /^(\d{4})[-/.](\d{2})[-/.](\d{2})$/;
            const yearMonthPattern = /^(\d{4})[-/.](\d{2})$/;
            if (yearMonthDayPattern.test(dateStr)) {
                const [_, year, month, day] = dateStr.match(yearMonthDayPattern);
                return `${year}年${month}月${day}日`;
            }
            else if (yearMonthPattern.test(dateStr)) {
                const [_, year, month] = dateStr.match(yearMonthPattern);
                return `${year}年${month}月`;
            }
            else {
                throw new Error('输入的日期格式不正确，应该是"YYYY-MM"或"YYYY-MM-DD"格式的字符串');
            }
        }
        catch (error) {
            return dateStr;
        }
    }
    // 格式化手机号，中间四位用星号替换
    static formatMobile(mobile) {
        if (mobile.length === 11) {
            return mobile.replace(/(\d{3})\d{4}(\d{4})/, '$1****$2');
        }
        else {
            return mobile;
        }
    }
    static color16() {
        var r = Math.floor(Math.random() * 256);
        var g = Math.floor(Math.random() * 256);
        var b = Math.floor(Math.random() * 256);
        var color = '#' + r.toString(16) + g.toString(16) + b.toString(16);
        return color;
    }
    static getFrameCity() {
        let finale_frame_city = "";
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getCityInfo, {}, (info) => {
            if (this.isObject(info)) {
                let { frame_city } = info;
                finale_frame_city = this.$string(frame_city);
            }
        });
        return finale_frame_city;
    }
    static getUserFid() {
        let user_fid = "";
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserFid, {}, (info) => {
            if (this.isObject(info)) {
                let { user_fid } = info;
                user_fid = this.$string(user_fid);
            }
        });
        return user_fid;
    }
    static getDeviceInfo(callback) {
        HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.getDeviceInfo, {}, (info) => {
            if (this.isObject(info)) {
                if (callback) {
                    callback(info);
                }
            }
        });
    }
}

class HLLUShareOrderDotModel {
    constructor() {
        this.red_num = 0;
        this.last_order_time = 0;
    }
    static createShareOrderDotModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { red_num, last_order_time } = info;
            model.red_num = HLLUTools.$number(red_num);
            model.last_order_time = HLLUTools.$number(last_order_time);
        }
        return model;
    }
}

class HLLUProfileCreditModel {
    constructor() {
        this.has_contorl = 0;
        this.has_cover = 0;
        this.has_warning = 0;
        this.data_version = "";
    }
    static createProfileCreditModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { has_contorl, has_cover, has_warning, data_version } = info;
            model.has_contorl = HLLUTools.$number(has_contorl);
            model.has_cover = HLLUTools.$number(has_cover);
            model.has_warning = HLLUTools.$number(has_warning);
            model.data_version = HLLUTools.$string(data_version);
        }
        return model;
    }
}

var HLLUCornerType;
(function (HLLUCornerType) {
    HLLUCornerType[HLLUCornerType["None"] = 0] = "None";
    HLLUCornerType[HLLUCornerType["Text"] = 1] = "Text";
    HLLUCornerType[HLLUCornerType["RedSpot"] = 2] = "RedSpot";
    HLLUCornerType[HLLUCornerType["NumberSpot"] = 3] = "NumberSpot";
})(HLLUCornerType || (HLLUCornerType = {}));
class HLLUPersonalListItemModel {
    constructor() {
        this.action_link = "";
        this.content = "";
        this.corner_bottom_title = "";
        this.corner_top_right = 0;
        this.corner_end_time = 0;
        this.corner_start_time = 0;
        this.corner_text = "";
        this.profile_credit_info = new HLLUProfileCreditModel;
        this.red_mark = 0;
        this.ad_id = "";
        this.corner_click_show = 0;
        this.ad_material_id = "";
        this.action_type = 0;
        this.can_share = 0;
        this.share_to = "";
        this.name = "";
        this.share_content = "";
        this.share_icon_url = "";
        this.share_url = "";
        this._su = "";
        this.wx_link_id = "";
        this.isAll = false;
        this.cornerType = HLLUCornerType.None;
        this.hasBeenClicked = false;
        this.shouldShowCorner = false;
        this.unreadMessageCount = 0;
        this.last_order_time = 0;
        this.ads_exposure_url = "";
        this.ads_log_commonparam = "";
        this.ads_hit_url = "";
        // 端上订单共享记录时间
        this.shareOrderLastTimeStamp = 0;
    }
    static createPersonalListItem(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { ad_material_id, ads_hit_url, ads_exposure_url, ads_log_commonparam, corner_click_show, ad_id, action_link, content, corner_bottom_title, corner_top_right, corner_end_time, corner_start_time, corner_text, profile_credit_info, red_mark, action_type, can_share, share_to, name, share_content, share_icon_url, share_url, _su, wx_link_id, unreadMessageCount } = info;
            model.action_link = HLLUTools.$string(action_link);
            model.content = HLLUTools.$string(content);
            model.name = HLLUTools.$string(name);
            model.corner_bottom_title = HLLUTools.$string(name);
            model.corner_top_right = HLLUTools.$number(corner_top_right);
            model.corner_end_time = HLLUTools.$number(corner_end_time);
            model.corner_start_time = HLLUTools.$number(corner_start_time);
            model.corner_text = HLLUTools.$string(corner_text);
            model.profile_credit_info = HLLUProfileCreditModel.createProfileCreditModel(profile_credit_info);
            model.red_mark = HLLUTools.$number(red_mark);
            model.ad_id = HLLUTools.$string(ad_id);
            model.corner_click_show = HLLUTools.$number(corner_click_show);
            model.action_type = HLLUTools.$number(action_type);
            model.can_share = HLLUTools.$number(can_share);
            model.share_to = HLLUTools.$string(share_to);
            model.share_content = HLLUTools.$string(share_content);
            model.share_icon_url = HLLUTools.$string(share_icon_url);
            model.share_url = HLLUTools.$string(share_url);
            model._su = HLLUTools.$string(_su);
            model.wx_link_id = HLLUTools.$string(wx_link_id);
            model.unreadMessageCount = HLLUTools.$number(unreadMessageCount);
            model.ads_exposure_url = HLLUTools.$string(ads_exposure_url);
            model.ads_log_commonparam = HLLUTools.$string(ads_log_commonparam);
            model.ads_hit_url = HLLUTools.$string(ads_hit_url);
            model.ad_material_id = HLLUTools.$string(ad_material_id);
        }
        return model;
    }
    static createPersonalItemList(list) {
        let models = [];
        if (HLLUTools.isArray(list)) {
            list.forEach(item => {
                let model = this.createPersonalListItem(item);
                if (model) {
                    models.push(model);
                }
            });
        }
        return models;
    }
}

class HLLUModuleConfigModel {
    constructor() {
        this.name = "";
        this.keyword = "";
        this.list = [];
    }
    static createModuleConfigModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { name, keyword } = info;
            model.name = HLLUTools.$string(name);
            model.keyword = HLLUTools.$string(keyword);
        }
        return model;
    }
}

var HLLUAlpha;
(function (HLLUAlpha) {
    HLLUAlpha["p100"] = "FF";
    HLLUAlpha["p85"] = "D9";
    HLLUAlpha["p70"] = "B3";
    HLLUAlpha["p65"] = "A6";
    HLLUAlpha["p50"] = "80";
    HLLUAlpha["p45"] = "73";
    HLLUAlpha["p25"] = "40";
    HLLUAlpha["p20"] = "33";
    HLLUAlpha["p12"] = "1F";
    HLLUAlpha["p9"] = "17";
    HLLUAlpha["p6"] = "0F";
})(HLLUAlpha || (HLLUAlpha = {}));
var HLLUColorValue;
(function (HLLUColorValue) {
    HLLUColorValue["white"] = "#ffffff";
    HLLUColorValue["black"] = "#000000";
    HLLUColorValue["themeColor"] = "#ff6600";
    HLLUColorValue["mainBgColor"] = "#F7F7F7";
    HLLUColorValue["f3f4f5"] = "#F3F4F5";
    HLLUColorValue["fdf1e7"] = "#FDF1E7";
    HLLUColorValue["e5e5e5"] = "#E5E5E5";
    HLLUColorValue["FFF1E8"] = "#FFF1E8";
    HLLUColorValue["FF3B30"] = "#FF3B30";
    HLLUColorValue["L222836"] = "#222836";
    HLLUColorValue["FEF3EB"] = "#FEF3EB";
    HLLUColorValue["FFDFCC"] = "#FFDFCC";
    HLLUColorValue["FFBA15"] = "#FFBA15";
    HLLUColorValue["B2B08"] = "#9B2B08";
    HLLUColorValue["C222836"] = "#222836";
})(HLLUColorValue || (HLLUColorValue = {}));
var HLLUFontWeight;
(function (HLLUFontWeight) {
    HLLUFontWeight[HLLUFontWeight["UltraLight"] = 0] = "UltraLight";
    HLLUFontWeight[HLLUFontWeight["Thin"] = 1] = "Thin";
    HLLUFontWeight[HLLUFontWeight["Light"] = 2] = "Light";
    HLLUFontWeight[HLLUFontWeight["Regular"] = 3] = "Regular";
    HLLUFontWeight[HLLUFontWeight["Medium"] = 4] = "Medium";
    HLLUFontWeight[HLLUFontWeight["Semibold"] = 5] = "Semibold";
    HLLUFontWeight[HLLUFontWeight["Bold"] = 6] = "Bold";
    HLLUFontWeight[HLLUFontWeight["Heavy"] = 7] = "Heavy";
    HLLUFontWeight[HLLUFontWeight["Black"] = 8] = "Black";
})(HLLUFontWeight || (HLLUFontWeight = {}));
var HLLUFontStyle;
(function (HLLUFontStyle) {
    HLLUFontStyle["none"] = "none";
    HLLUFontStyle["bold"] = "bold";
    HLLUFontStyle["italic"] = "italic";
    HLLUFontStyle["boldAndItalic"] = "boldAndItalic";
})(HLLUFontStyle || (HLLUFontStyle = {}));
var HLLUTextAlignment;
(function (HLLUTextAlignment) {
    HLLUTextAlignment["left"] = "left";
    HLLUTextAlignment["center"] = "center";
    HLLUTextAlignment["right"] = "right";
})(HLLUTextAlignment || (HLLUTextAlignment = {}));

const HLLUIHelper = {
    createLabel(text, color, font, textAlign = HLLUTextAlignment.left) {
        let textView = new paladin.TextView;
        textView.text = text;
        textView.textColor = color;
        textView.textAlignment = textAlign;
        textView.textSize = font.fontSize;
        textView.fontStyle = font.fontStyle;
        textView.fontWeight = Number(font.fontWeight);
        return textView;
    }
};

class HLLUColor {
    static get white() {
        return HLLUColor.colorWithHex(HLLUColorValue.white);
    }
    static get black() {
        return HLLUColor.colorWithHex(HLLUColorValue.black);
    }
    static colorWithHex(hex, alpha = HLLUAlpha.p100) {
        let color = "";
        if (hex.startsWith("#") && hex.length == 7) {
            let temp = hex.split("#");
            if (temp.length == 2) {
                color = "#" + alpha + temp[1];
            }
        }
        return color;
    }
}

class HLLUFont {
    set fontSize(fontSize) {
        this._fontSize = fontSize;
    }
    get fontSize() {
        return this._fontSize;
    }
    set fontWeight(fontWeight) {
        this._fontWeight = fontWeight;
    }
    get fontWeight() {
        return this._fontWeight;
    }
    set fontStyle(fontStyle) {
        this._fontStyle = fontStyle;
    }
    get fontStyle() {
        return this._fontStyle;
    }
    static fontWithParams(fontSize, fontWeight = HLLUFontWeight.Regular, fontStyle = HLLUFontStyle.none) {
        let font = new HLLUFont;
        font.fontSize = fontSize;
        font.fontWeight = fontWeight;
        font.fontStyle = fontStyle;
        return font;
    }
}

const HLLUImageBundle = {
    path: "HLLUser",
    name: "HLLUser"
};
var HLLUImageNames;
(function (HLLUImageNames) {
    HLLUImageNames["ic_default_avatar"] = "ic_default_avatar";
    HLLUImageNames["ic_scan_new"] = "ic_scan_new";
    HLLUImageNames["ic_setting_new"] = "ic_setting_new";
    HLLUImageNames["ic_evaluate_score"] = "ic_evaluate_score";
    HLLUImageNames["ic_auth_arrow"] = "ic_auth_arrow";
    HLLUImageNames["ic_trangle_top"] = "ic_trangle_top";
    HLLUImageNames["ic_ar_scan_entry"] = "ic_ar_scan_entry";
    HLLUImageNames["ic_qr_entry"] = "ic_qr_entry";
    HLLUImageNames["ic_personal_more_adv"] = "ic_personal_more_adv";
    HLLUImageNames["ic_person_corner_left"] = "ic_person_corner_left";
    HLLUImageNames["ic_home_force_alert_line"] = "ic_home_force_alert_line";
    HLLUImageNames["ic_home_force_alert_line_up"] = "ic_guide_line_up";
})(HLLUImageNames || (HLLUImageNames = {}));

/**
 * Get bundle path
 *
 * @export
 * @param {String} className
 * @param {String} resource
 * @return {*}  {string}
 */
function bundlePath(className, resource) {
    const wrappedParam = { "class": className, "resource": resource };
    let url = '';
    wrappedParam.success = (response) => {
        var _a;
        url = (_a = response["url"]) !== null && _a !== void 0 ? _a : '';
    };
    context.sendMessage("bundle", "bundlePath", wrappedParam);
    return url;
}

/**
 * request function, which provides native network requests
 *
 * @memberOfBridge network
 *
 * @param param
 * @param param.params Parameters required in a request. You can put any data required by native side.
 *                     The definitions of fields in the params need to be aligned on both iOS and Android.
 * @param param.usedCache Whether to use cache or not.
 * @param param.method request method  POST or GET
 * @param param.onSuccess callback called when the request succeeds
 * @param param.onFail callback called when the request fails
 */
var RequestMethod;
(function (RequestMethod) {
    RequestMethod["Post"] = "POST";
    RequestMethod["Get"] = "GET";
})(RequestMethod || (RequestMethod = {}));

/**
 * This function deletes the specified locally stored value
 *
 * @memberOfBridge storage
 *
 * @param {string} key The key of the to-be-deleted value
 */
function remove(key) {
    context.sendMessage("storage", "remove", { key });
}
/**
 * The function to retrieve locally stored data
 *
 * @memberOfBridge storage
 *
 * @param {string} key The key of the target value
 *
 * @returns {string} the value corresponding to the key
 */
function retrieve(key) {
    return context.sendMessage("storage", "retrieve", { key });
}
/**
 * The function to write/store to local storage, which provids the ability to
 * persist the data into the local file system
 *
 * @memberOfBridge storage
 *
 * @param {string} key
 * @param {string} value
 * @returns {boolean} whether the store action succeeded
 */
function store(key, value) {
    return context.sendMessage("storage", "store", { key, value });
}

/**
 * Broadcast channel
 *
 * @Android availble in Android
 * @iOS not availble in iOS
 */
var BroadcastChannel;
(function (BroadcastChannel) {
    /**
     * support the LocalBroadcastManager channel in the bundle
     */
    BroadcastChannel[BroadcastChannel["LOCAL"] = 0] = "LOCAL";
    /**
     * By using SYSTEM, data will broadcasted directly through the system broadcast channel
     */
    BroadcastChannel[BroadcastChannel["SYSTEM"] = 1] = "SYSTEM";
    /**
     * Support both local and sysyem channel
     */
    BroadcastChannel[BroadcastChannel["ALL"] = 2] = "ALL";
})(BroadcastChannel || (BroadcastChannel = {}));
/**
 * Send broadcast
 * The broadcast can be received by the callback passed into the subscribe function,
 * or it can be received by the native receiver.
 *
 * @memberOfBridge broadcast
 *
 * @param action broadcast name
 * @param config
 * @param config.info Additional information carried by the broadcast
 * @param config.channel Android only, LOCAL by default
 */
function publish(action, config) {
    const arg = { action };
    if (config) {
        if (config.info) {
            arg.info = config.info;
        }
        if (typeof config.channel !== "undefined") {
            arg.channel = config.channel;
        }
    }
    context.sendMessage("broadcast", "publish", arg);
}

// 导航高度
// 角标点击标识前缀
const kCornerClickPreFlag = 'kCornerClickPreFlag';
// 信用评价存储标识前缀
const kCreditFlag = 'kCreditFlag';
// 是否进入过订单共享的标识
const kHasEnterOrderShareFlag = 'kHasEnterOrderShareFlag';
// 监听刷新页面的通知
const kRefreshPageNotification = 'kRefreshPageNotification';

class HLLUElementItemView extends paladin$1.View {
    constructor() {
        super(...arguments);
        this.model = new HLLUPersonalListItemModel();
        this.index = 0;
        this.moduleName = "";
        this.allModel = new HLLUModuleConfigModel();
        /// 角标，给引导用的
        this.subArrowView = null;
        this.islogin = false;
        this.isGuide = false;
    }
    static createElementItemView(model, size, index, moduleName, islogin, isGuide) {
        let view = new this;
        view.size = size;
        view.model = model;
        view.index = index;
        view.moduleName = moduleName;
        view.islogin = islogin;
        if (isGuide != null && isGuide == true) {
            view.isGuide = true;
        }
        view.layout();
        view.onClick = () => {
            if (view.clickItemCallBack) {
                view.clickItemCallBack();
            }
            view.clickAction();
        };
        return view;
    }
    clickAction() {
        let { isAll, ads_exposure_url, ads_hit_url, ads_log_commonparam, corner_click_show, cornerType, corner_bottom_title, profile_credit_info, action_link, last_order_time, ad_id, _su } = this.model;
        if (corner_click_show == 1) {
            store(kCornerClickPreFlag + this.model.ad_id, "" + new Date().getTime());
        }
        publish(kRefreshPageNotification);
        if (cornerType == HLLUCornerType.RedSpot) {
            store(kCornerClickPreFlag + this.model.ad_id, "" + new Date().getTime());
            this.model.red_mark = 0;
            if (corner_bottom_title == "客户管理") {
                // 客户管理小红点已读上报
                HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserToken, {}, (info) => {
                    if (HLLUTools.isObject(info)) {
                        let { token } = info;
                        let item = {
                            method: HLLUMethod.customSetReadDot,
                            params: {
                                token
                            }
                        };
                        fetch(item);
                    }
                });
            }
        }
        if (cornerType == HLLUCornerType.Text && corner_bottom_title == "信用评价") {
            let closeTime = new Date().getTime();
            let dataVersion = profile_credit_info.data_version;
            HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserFid, {}, (info) => {
                if (HLLUTools.isObject(info)) {
                    let { user_fid } = info;
                    let userFid = HLLUTools.$string(user_fid);
                    if (userFid.length > 0) {
                        let dataVersionInfo = {
                            closeTime,
                            dataVersion
                        };
                        store(kCreditFlag + userFid, JSON.stringify(dataVersionInfo));
                    }
                }
            });
        }
        if (action_link == 'share_order') {
            store(kHasEnterOrderShareFlag, "1");
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.setLastEnterShareOrderTimestamp, {
                'last_order_timestamp': last_order_time
            });
        }
        // 点击上报神策，只报新的埋点
        HLLUBridge.sendTrackSensorEvent({
            name: "personal_center_NEW",
            properties: {
                event_type: "点击",
                frame_city: HLLUTools.getFrameCity(),
                button_type: corner_bottom_title,
                module_type: this.moduleName
            }
        });
        // 点击上报广告
        if (!isAll) {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.reportAdvertiseSensor, {
                url: ads_hit_url,
                parameter: ads_log_commonparam,
                adIds: {}
            });
            if (corner_bottom_title == '余额') {
                if (this.islogin) {
                    HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.openWalletyPageEvent);
                }
                else {
                    HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.openLoginPageEvent);
                }
            }
            else if (corner_bottom_title == '优惠券') {
                if (this.islogin) {
                    HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.openCouponPageEvent);
                }
                else {
                    HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.openLoginPageEvent);
                }
            }
            else if (corner_bottom_title == '地址上报' && PLDEnvironment.platform.toLowerCase() == 'ios') {
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.openAddressUploadPageEvent);
            }
            else {
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickPersonalEntranceCommonEvent, this.model);
            }
        }
        else {
            // 跳转更多服务
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.openMoreServicePageEvent, {
                title: '全部服务',
                more_data: this.allModel
            });
        }
    }
    layout() {
        let imageView = this.createHeaderAvatarImageView();
        imageView.centerX = this.centerX;
        if (this.isGuide == true) {
            imageView.y = 3;
        }
        this.addSubView(imageView);
        let titleLabel = this.createTitleLabel();
        titleLabel.centerX = this.centerX;
        titleLabel.top = imageView.bottom + 2;
        this.addSubView(titleLabel);
        // 曝光上报神策，只报新的埋点
        let { corner_bottom_title, ads_exposure_url, ads_log_commonparam } = this.model;
        HLLUBridge.sendTrackSensorEvent({
            name: "personal_center_NEW",
            properties: {
                event_type: "曝光",
                frame_city: HLLUTools.getFrameCity(),
                button_type: corner_bottom_title,
                module_type: this.moduleName
            },
            needControl: true
        });
    }
    createHeaderAvatarImageView() {
        let imageView = new paladin$1.ImageView;
        if (this.model.isAll) {
            imageView.image = HLLUImageNames.ic_personal_more_adv;
            imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        }
        else {
            imageView.imageUrl = this.model.content;
        }
        imageView.width = 28;
        imageView.height = 28;
        return imageView;
    }
    createTitleLabel() {
        let label = HLLUIHelper.createLabel(this.generateFitableTitle(this.model.corner_bottom_title), HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p85), HLLUFont.fontWithParams(12));
        label.sizeToFit();
        label.height = 18;
        return label;
    }
    generateFitableTitle(title) {
        if (title.length == 5) {
            return title;
        }
        if (title.length > 4) {
            title = title.substring(0, 4) + "...";
        }
        return title;
    }
}

class HLLUCornerView extends paladin.View {
    constructor() {
        super(...arguments);
        this.model = new HLLUPersonalListItemModel;
    }
    static createCornerView() {
        let view = new this;
        return view;
    }
    layout() {
        if (this.model.cornerType === HLLUCornerType.Text) {
            let view = new paladin.View;
            view.borderColor = HLLUColorValue.white;
            view.borderWidth = 1;
            view.cornerRadius = 8;
            view.height = 17;
            view.backgroundColor = HLLUColorValue.themeColor;
            let titleLabel = this.createTitleLabel();
            view.width = titleLabel.width + 8;
            titleLabel.center = view.center;
            let leftImageView = this.createLeftImageView();
            leftImageView.centerY = view.centerY + 0.5;
            this.addSubView(view);
            view.addSubView(titleLabel);
            this.addSubView(leftImageView);
            this.width = view.width;
            this.height = view.height;
        }
        else if (this.model.cornerType === HLLUCornerType.RedSpot) {
            this.width = 8;
            this.height = 8;
            this.cornerRadius = 4;
            this.backgroundColor = HLLUColorValue.FF3B30;
        }
        else if (this.model.cornerType === HLLUCornerType.NumberSpot) {
            let { unreadMessageCount } = this.model;
            if (unreadMessageCount == 0) {
                return;
            }
            let finalNumStr = unreadMessageCount + '';
            if (unreadMessageCount > 99) {
                finalNumStr = "...";
            }
            this.width = 16;
            this.height = 16;
            this.cornerRadius = 8;
            this.backgroundColor = HLLUColorValue.FF3B30;
            this.borderColor = HLLUColorValue.white;
            this.borderWidth = 1;
            let label = HLLUIHelper.createLabel(`${finalNumStr}`, HLLUColorValue.white, HLLUFont.fontWithParams(10, HLLUFontWeight.Bold));
            label.sizeToFit();
            this.addSubView(label);
            label.center = this.center;
            if (unreadMessageCount > 99) {
                label.top = label.top - 3;
            }
        }
    }
    createTitleLabel() {
        let label = HLLUIHelper.createLabel(this.model.corner_text, HLLUColorValue.white, HLLUFont.fontWithParams(10, HLLUFontWeight.Bold));
        label.sizeToFit();
        return label;
    }
    createLeftImageView() {
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_person_corner_left;
        imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imageView.width = 8;
        imageView.height = 18;
        return imageView;
    }
}

class HLLUModuleMoreBoxView extends paladin.View {
    constructor() {
        super(...arguments);
        this.shareOrderDotModel = new HLLUShareOrderDotModel();
        this.model = new HLLUModuleConfigModel();
        this.unreadMessageCount = 0;
    }
    static createInformationView(width) {
        let view = new this;
        view.width = width;
        return view;
    }
    layout() {
        // 创建背景图
        let bgView = this.createBgView();
        this.addSubView(bgView);
        let lastView;
        // 去掉全部服务
        let allServiceItem = this.model.list.find(item => item.corner_bottom_title == '全部服务');
        if (allServiceItem) {
            this.model.list.splice(this.model.list.indexOf(allServiceItem), 1);
        }
        // 创建广告位
        let itemWidth = (this.width - 32) / 4;
        for (let i = 0; i < this.model.list.length; i++) {
            let item = this.model.list[i];
            let itemView = HLLUElementItemView.createElementItemView(item, { width: itemWidth, height: 48 }, i, this.model.name, false);
            itemView.clickItemCallBack = this.clickCallback;
            itemView.allModel = this.model;
            bgView.addSubView(itemView);
            let row = i % 4;
            if (row == 0) {
                itemView.left = 16;
            }
            else {
                itemView.left = lastView.right;
            }
            let col = Math.floor(i / 4);
            itemView.top = 12 + col * (itemView.height + 20);
            lastView = itemView;
            this.configCornerType(item);
            // 开始处理角标处理展示 
            if (item.cornerType != HLLUCornerType.None) {
                let cornerTextView = HLLUCornerView.createCornerView();
                cornerTextView.model = item;
                cornerTextView.layout();
                if (item.cornerType == HLLUCornerType.Text) {
                    cornerTextView.left = itemView.width / 2 + itemView.left;
                    cornerTextView.top = itemView.top - 8;
                }
                else if (item.cornerType == HLLUCornerType.RedSpot) {
                    cornerTextView.left = itemView.left + itemView.width * 2 / 3;
                    cornerTextView.top = itemView.top - 8;
                }
                else if (item.cornerType == HLLUCornerType.NumberSpot) {
                    cornerTextView.left = itemView.width * 2 / 3 + itemView.left;
                    cornerTextView.top = itemView.top - 8;
                }
                bgView.addSubView(cornerTextView);
            }
        }
        if (lastView) {
            bgView.height = lastView.bottom + 16;
        }
        this.height = bgView.bottom;
    }
    configCornerType(item) {
        let { corner_click_show, red_mark, corner_text, ad_id, corner_top_right, corner_end_time, corner_start_time, profile_credit_info, corner_bottom_title } = item;
        let currentTime = new Date().getTime() / 1000;
        if (corner_click_show == 1 && ad_id.length > 0) {
            // 是否点击过
            let adIdFlag = retrieve(kCornerClickPreFlag + ad_id);
            if (adIdFlag) {
                item.hasBeenClicked = true;
            }
        }
        // 最终判断是否展示角标
        item.shouldShowCorner = item.corner_top_right == 1 && currentTime <= corner_end_time && currentTime >= corner_start_time && !item.hasBeenClicked;
        if (item.shouldShowCorner) {
            item.cornerType = HLLUCornerType.Text;
        }
        if (corner_bottom_title == '信用评价') {
            let isShowCreditEvaluationCorner = profile_credit_info.has_contorl == 1 || profile_credit_info.has_warning == 1;
            let isNOLimit = this.isShowCreditEvaluationCorner(profile_credit_info.data_version);
            if (isShowCreditEvaluationCorner && isNOLimit) {
                item.corner_text = "请关注";
                item.cornerType = HLLUCornerType.Text;
            }
        }
        if (!item.shouldShowCorner && red_mark == 1) {
            item.shouldShowCorner = true;
            item.cornerType = HLLUCornerType.RedSpot;
        }
        if (item.hasBeenClicked) {
            item.cornerType = HLLUCornerType.None;
        }
        if (corner_bottom_title == '我的司机' || corner_bottom_title == '收藏司机') {
            item.cornerType = HLLUCornerType.NumberSpot;
        }
        if (corner_bottom_title == '订单共享') {
            this.setShareOrderCorner(item);
        }
    }
    setShareOrderCorner(item) {
        item.cornerType = HLLUCornerType.None;
        let hasEnter = retrieve(kHasEnterOrderShareFlag);
        if (!hasEnter) {
            item.corner_text = "New";
            item.cornerType = HLLUCornerType.Text;
            return;
        }
        item.cornerType = HLLUCornerType.NumberSpot;
        HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.getLastEnterShareOrderTimestamp, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { last_order_timestamp } = info;
                last_order_timestamp = HLLUTools.$number(last_order_timestamp);
                let { red_num, last_order_time } = this.shareOrderDotModel;
                item.last_order_time = last_order_time;
                if (red_num > 0) {
                    // 展示数字角标
                    item.cornerType = HLLUCornerType.NumberSpot;
                    item.unreadMessageCount = red_num;
                }
                else if (last_order_time > last_order_timestamp) {
                    // 展示红点角标
                    item.cornerType = HLLUCornerType.RedSpot;
                }
            }
        });
    }
    isShowCreditEvaluationCorner(currentDataVersion) {
        let userFid = "";
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserFid, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { user_fid } = info;
                userFid = HLLUTools.$string(user_fid);
            }
        });
        if (userFid.length > 0) {
            let creditEvaluationInfoString = retrieve(kCreditFlag + userFid);
            if (creditEvaluationInfoString.length > 0) {
                let creditCacheDic = JSON.parse(creditEvaluationInfoString);
                if (HLLUTools.isObject(creditCacheDic)) {
                    let { closeTime, dataVersion } = creditCacheDic;
                    if (closeTime <= 0) {
                        return true;
                    }
                    let nowTime = new Date().getTime();
                    if (nowTime < closeTime) {
                        return true;
                    }
                    // 距离上一次点击关闭角标是否超过了七天 如果超过七天有数据便展示且清除上次关闭时间 没有超过不展示
                    let timeDifferenceValue = (nowTime - closeTime) / 60 / 60 / 24;
                    let isConformLimit = timeDifferenceValue > 7;
                    let isDataVersionLimit = currentDataVersion == dataVersion;
                    if (isConformLimit) {
                        //距离上次点击关闭角标超过七天 清除上次关闭时间
                        remove(kCreditFlag + userFid);
                    }
                    return isConformLimit && isDataVersionLimit;
                }
            }
        }
        return false;
    }
    createBgView() {
        let bgView = new paladin.View;
        bgView.left = 0;
        bgView.width = this.width;
        return bgView;
    }
}

class HLLUPersonalAdvMoreVC extends paladin.VC {
    constructor() {
        super(...arguments);
        // 订单共享入口红点模型数据
        this.shareOrderDotModel = new HLLUShareOrderDotModel;
        // 收藏司机的未读消息数
        this.unreadMessageCount = 0;
        this.moreData = {};
    }
    onLoad() {
        this.startMouldeRequest();
    }
    layout() {
        const bgView = paladin.View.viewWithFrame(0, 0, this.width, this.height);
        // 创建滚动底图
        let bgScrollView = this.createBgScrollView();
        bgView.addSubView(bgScrollView);
        // 获取初始数据
        let moduleView = this.createModuleMoreBoxView(this.moreData);
        bgScrollView.addSubView(moduleView);
        return bgView;
    }
    createBgScrollView() {
        let view = new paladin.ScrollView;
        view.left = 0;
        view.top = 0;
        view.width = this.width;
        view.height = this.height;
        return view;
    }
    startMouldeRequest() {
        this.getShareOrderBadgeData();
        HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.getMoreServiceData, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { more_data } = info;
                this.moreData = more_data;
                this.needLayout();
            }
        });
    }
    // 获取共享订单角标数据
    getShareOrderBadgeData() {
        let item = {
            method: HLLUMethod.getShareOrderEntranceRedDot,
            params: {},
        };
        fetch(item, (result) => {
            this.shareOrderDotModel = HLLUShareOrderDotModel.createShareOrderDotModel(result);
            this.needLayout();
        });
    }
    createModuleMoreBoxView(item) {
        let moduleView = HLLUModuleMoreBoxView.createInformationView(this.width);
        moduleView.model = item;
        moduleView.shareOrderDotModel = this.shareOrderDotModel;
        moduleView.unreadMessageCount = this.unreadMessageCount;
        moduleView.clickCallback = () => {
            setTimeout(() => {
                this.needLayout();
            }, 300);
        };
        moduleView.layout();
        // 进行广告曝光
        let firstItem = new HLLUPersonalListItemModel();
        if (item.list.length > 0) {
            firstItem = item.list[0];
        }
        let showStringArray = [];
        let adMaterialStringArray = [];
        let bottomTitleStringArray = [];
        for (let i = 0; i < item.list.length; i++) {
            let model = item.list[i];
            showStringArray.push(model.ad_id);
            adMaterialStringArray.push(model.ad_material_id);
            bottomTitleStringArray.push(model.corner_bottom_title);
        }
        let showString = showStringArray.join("-");
        let adMaterialString = adMaterialStringArray.join("-");
        let showStringSensorsAnalytics = showStringArray.join(",");
        let bottomTitleString = bottomTitleStringArray.join(",");
        let adIds = {
            ides: showString,
            adMaterialId: adMaterialString
        };
        let hasSensored = HLLUSensorControl.getInstance().sensorDict[JSON.stringify(adIds)];
        if (!hasSensored) {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.reportAdvertiseSensor, {
                url: firstItem.ads_exposure_url,
                parameter: firstItem.ads_log_commonparam,
                adIds
            });
            HLLUSensorControl.getInstance().sensorDict[JSON.stringify(adIds)] = true;
        }
        // 将神策的也加上
        HLLUBridge.sendTrackSensorEvent({
            name: "advertise_resource_expo",
            properties: {
                advertise_type: item.name,
                ad_id_list: showStringSensorsAnalytics,
                ad_title_list: bottomTitleString,
                trigger_time: new Date().getTime() + "",
                ad_city: HLLUTools.getFrameCity()
            },
            needControl: true,
            specialSensor: JSON.stringify({
                advertise_type: item.name,
                ad_id_list: showStringSensorsAnalytics,
                ad_title_list: bottomTitleString,
                ad_city: HLLUTools.getFrameCity(),
            })
        });
        return moduleView;
    }
}
Paladin.Page(HLLUPersonalAdvMoreVC);
//# sourceMappingURL=hllu-personal-adv-more-bundle.js.map
