'use strict';

var paladin = require('@pld/paladin');
var paladin$1 = require('@pld/paladin');

var HLLUAlpha;
(function (HLLUAlpha) {
    HLLUAlpha["p100"] = "FF";
    HLLUAlpha["p85"] = "D9";
    HLLUAlpha["p70"] = "B3";
    HLLUAlpha["p65"] = "A6";
    HLLUAlpha["p50"] = "80";
    HLLUAlpha["p45"] = "73";
    HLLUAlpha["p25"] = "40";
    HLLUAlpha["p20"] = "33";
    HLLUAlpha["p12"] = "1F";
    HLLUAlpha["p9"] = "17";
    HLLUAlpha["p6"] = "0F";
})(HLLUAlpha || (HLLUAlpha = {}));
var HLLUColorValue;
(function (HLLUColorValue) {
    HLLUColorValue["white"] = "#ffffff";
    HLLUColorValue["black"] = "#000000";
    HLLUColorValue["themeColor"] = "#ff6600";
    HLLUColorValue["mainBgColor"] = "#F7F7F7";
    HLLUColorValue["f3f4f5"] = "#F3F4F5";
    HLLUColorValue["fdf1e7"] = "#FDF1E7";
    HLLUColorValue["e5e5e5"] = "#E5E5E5";
    HLLUColorValue["FFF1E8"] = "#FFF1E8";
    HLLUColorValue["FF3B30"] = "#FF3B30";
    HLLUColorValue["L222836"] = "#222836";
    HLLUColorValue["FEF3EB"] = "#FEF3EB";
    HLLUColorValue["FFDFCC"] = "#FFDFCC";
    HLLUColorValue["FFBA15"] = "#FFBA15";
    HLLUColorValue["B2B08"] = "#9B2B08";
    HLLUColorValue["C222836"] = "#222836";
})(HLLUColorValue || (HLLUColorValue = {}));
var HLLUFontWeight;
(function (HLLUFontWeight) {
    HLLUFontWeight[HLLUFontWeight["UltraLight"] = 0] = "UltraLight";
    HLLUFontWeight[HLLUFontWeight["Thin"] = 1] = "Thin";
    HLLUFontWeight[HLLUFontWeight["Light"] = 2] = "Light";
    HLLUFontWeight[HLLUFontWeight["Regular"] = 3] = "Regular";
    HLLUFontWeight[HLLUFontWeight["Medium"] = 4] = "Medium";
    HLLUFontWeight[HLLUFontWeight["Semibold"] = 5] = "Semibold";
    HLLUFontWeight[HLLUFontWeight["Bold"] = 6] = "Bold";
    HLLUFontWeight[HLLUFontWeight["Heavy"] = 7] = "Heavy";
    HLLUFontWeight[HLLUFontWeight["Black"] = 8] = "Black";
})(HLLUFontWeight || (HLLUFontWeight = {}));
var HLLUFontStyle;
(function (HLLUFontStyle) {
    HLLUFontStyle["none"] = "none";
    HLLUFontStyle["bold"] = "bold";
    HLLUFontStyle["italic"] = "italic";
    HLLUFontStyle["boldAndItalic"] = "boldAndItalic";
})(HLLUFontStyle || (HLLUFontStyle = {}));
var HLLUTextAlignment;
(function (HLLUTextAlignment) {
    HLLUTextAlignment["left"] = "left";
    HLLUTextAlignment["center"] = "center";
    HLLUTextAlignment["right"] = "right";
})(HLLUTextAlignment || (HLLUTextAlignment = {}));

const HLLUImageBundle = {
    path: "HLLUser",
    name: "HLLUser"
};
const HLLUPersonalCenterImageBundle = {
    path: "HLLPersonalCenter",
    name: "HLLPersonalCenter"
};
var HLLUImageNames;
(function (HLLUImageNames) {
    HLLUImageNames["ic_default_avatar"] = "ic_default_avatar";
    HLLUImageNames["ic_scan_new"] = "ic_scan_new";
    HLLUImageNames["ic_setting_new"] = "ic_setting_new";
    HLLUImageNames["ic_evaluate_score"] = "ic_evaluate_score";
    HLLUImageNames["ic_auth_arrow"] = "ic_auth_arrow";
    HLLUImageNames["ic_trangle_top"] = "ic_trangle_top";
    HLLUImageNames["ic_ar_scan_entry"] = "ic_ar_scan_entry";
    HLLUImageNames["ic_qr_entry"] = "ic_qr_entry";
    HLLUImageNames["ic_personal_more_adv"] = "ic_personal_more_adv";
    HLLUImageNames["ic_person_corner_left"] = "ic_person_corner_left";
    HLLUImageNames["ic_home_force_alert_line"] = "ic_home_force_alert_line";
    HLLUImageNames["ic_home_force_alert_line_up"] = "ic_guide_line_up";
})(HLLUImageNames || (HLLUImageNames = {}));

var HLLUMethod;
(function (HLLUMethod) {
    HLLUMethod["getUserInfo"] = "get_user_info";
    HLLUMethod["personalCenter"] = "personal_center";
    HLLUMethod["getShareOrderEntranceRedDot"] = "share_order_entrance_red_dot";
    HLLUMethod["customSetReadDot"] = "custom_set_read_dot";
    HLLUMethod["personalCenterGuidePop"] = "personal_center_guide_pop";
})(HLLUMethod || (HLLUMethod = {}));

class HLLUSensorControl {
    constructor() {
        this.sensorDict = {};
    }
    static getInstance() {
        let instance = HLLUSensorControl.instance;
        if (!instance) {
            instance = new HLLUSensorControl();
            HLLUSensorControl.instance = instance;
        }
        return instance;
    }
}

class HLLUBridge {
    static sendMessage(context, bridgeModule, methodName, param) {
        param.success = (result) => {
            if (param.successCallback) {
                param.successCallback(result);
            }
        };
        // 用于网络请求
        param.fail = (err) => {
            if (param.failureCallback) {
                param.failureCallback(err);
            }
        };
        context.sendMessage(bridgeModule, methodName, param);
    }
    // 埋点交互
    static sendTrackSensorEvent(params) {
        if (params.needControl) {
            // 控制曝光埋点次数
            if (params.specialSensor) {
                let hasSensored = HLLUSensorControl.getInstance().sensorDict[params.specialSensor];
                if (hasSensored) {
                    return;
                }
                HLLUSensorControl.getInstance().sensorDict[params.specialSensor] = true;
            }
            let hasSensored = HLLUSensorControl.getInstance().sensorDict[JSON.stringify(params.properties)];
            if (hasSensored) {
                return;
            }
            HLLUSensorControl.getInstance().sensorDict[JSON.stringify(params.properties)] = true;
        }
        this.sendMessage(context, 'hllUTrack', "tracWithParams", params);
    }
    // 网络请求
    static sendNetRequestEvent(type, method, params, successCallback = null, failureCallback = null) {
        this.sendMessage(context, "network", "request", {
            method: type,
            params: {
                args: Object.assign({}, params),
                method
            },
            successCallback,
            failureCallback
        });
    }
    // 用户基本信息
    static collectUserBaseInfo(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'HLLUUserBaseInfoBridge', methodName, params);
    }
    // 个人中心业务交互
    static sendPersonalCenterNativeEvent(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'HLLUPersonalCenterBridge', methodName, params);
    }
    // 基本能力桥接
    static sendCommonNativeEvent(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'HLLUCommonBridge', methodName, params);
    }
    // 原生modal交互
    static sendModalNativeEvent(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'modal', methodName, params);
    }
    static sendNavigatorNativeEvent(methodName, params = {}, success = null) {
        params.successCallback = success;
        this.sendMessage(context, 'navigator', methodName, params);
    }
}

var HLLUUserBaseInfoBridge;
(function (HLLUUserBaseInfoBridge) {
    HLLUUserBaseInfoBridge["getCityInfo"] = "getCityInfo";
    HLLUUserBaseInfoBridge["getLoginInfo"] = "getLoginInfo";
    HLLUUserBaseInfoBridge["getUserPhone"] = "getUserPhone";
    HLLUUserBaseInfoBridge["getHomepageChangeModeCount"] = "getHomepageChangeModeCount";
    HLLUUserBaseInfoBridge["getMDAPConfigForStringValue"] = "getMDAPConfigForStringValue";
    HLLUUserBaseInfoBridge["getUserFid"] = "getUserFid";
    HLLUUserBaseInfoBridge["getUserToken"] = "getUserToken";
})(HLLUUserBaseInfoBridge || (HLLUUserBaseInfoBridge = {}));
var HLLUPersonalCenterEventBridge;
(function (HLLUPersonalCenterEventBridge) {
    HLLUPersonalCenterEventBridge["checkIfShowSettingRedDot"] = "checkIfShowSettingRedDot";
    HLLUPersonalCenterEventBridge["clickSettingEvent"] = "clickSettingEvent";
    HLLUPersonalCenterEventBridge["getRecommendSwitch"] = "getRecommendSwitch";
    HLLUPersonalCenterEventBridge["sendUserInfoData"] = "sendUserInfoData";
    HLLUPersonalCenterEventBridge["clickAvatarOrLoginEvent"] = "clickAvatarOrLoginEvent";
    HLLUPersonalCenterEventBridge["clickUserOrderCompleteEvent"] = "clickUserOrderCompleteEvent";
    HLLUPersonalCenterEventBridge["clickStarRatingEvent"] = "clickStarRatingEvent";
    HLLUPersonalCenterEventBridge["clickEnterpriseAuthEvent"] = "clickEnterpriseAuthEvent";
    HLLUPersonalCenterEventBridge["getUnreadMessageCount"] = "getUnreadMessageCount";
    HLLUPersonalCenterEventBridge["getLastEnterShareOrderTimestamp"] = "getLastEnterShareOrderTimestamp";
    HLLUPersonalCenterEventBridge["clickPersonalEntranceCommonEvent"] = "clickPersonalEntranceCommonEvent";
    HLLUPersonalCenterEventBridge["setLastEnterShareOrderTimestamp"] = "setLastEnterShareOrderTimestamp";
    HLLUPersonalCenterEventBridge["reportAdvertiseSensor"] = "reportAdvertiseSensor";
    HLLUPersonalCenterEventBridge["openMoreServicePageEvent"] = "openMoreServicePageEvent";
    HLLUPersonalCenterEventBridge["getMoreServiceData"] = "getMoreServiceData";
    HLLUPersonalCenterEventBridge["openWalletyPageEvent"] = "openWalletyPageEvent";
    HLLUPersonalCenterEventBridge["openCouponPageEvent"] = "openCouponPageEvent";
    HLLUPersonalCenterEventBridge["getGuideCanShow"] = "getGuideCanShow";
    HLLUPersonalCenterEventBridge["saveGuideShowTime"] = "saveGuideShowTime";
    HLLUPersonalCenterEventBridge["openAddressUploadPageEvent"] = "openAddressUploadPageEvent"; // 打开地址上报页面事件
})(HLLUPersonalCenterEventBridge || (HLLUPersonalCenterEventBridge = {}));
var HLLUCommonEventBridge;
(function (HLLUCommonEventBridge) {
    // 1.页面返回
    HLLUCommonEventBridge["pageGoBack"] = "pageGoBack";
    // 2.展示吐司
    HLLUCommonEventBridge["showToast"] = "showToast";
    HLLUCommonEventBridge["openLoginPageEvent"] = "openLoginPageEvent";
    HLLUCommonEventBridge["openScanPageEvent"] = "openScanPageEvent";
    HLLUCommonEventBridge["openARPageEvent"] = "openARPageEvent";
    HLLUCommonEventBridge["getDeviceInfo"] = "getDeviceInfo"; // 获取设备信息
})(HLLUCommonEventBridge || (HLLUCommonEventBridge = {}));
var HLLUModalEventBridge;
(function (HLLUModalEventBridge) {
    // 1.展示Loading
    HLLUModalEventBridge["showLoading"] = "showLoading";
    // 2.隐藏Loading
    HLLUModalEventBridge["dismissLoading"] = "dismissLoading";
})(HLLUModalEventBridge || (HLLUModalEventBridge = {}));
var HLLUBroadCastEvent;
(function (HLLUBroadCastEvent) {
    // 1.监听登录成功的通知
    HLLUBroadCastEvent["kNotificationLogin"] = "kNotificationLogin";
    // 2.监听退出登录的通知
    HLLUBroadCastEvent["kNotificationLogout"] = "kNotificationLogout";
    // 3.展示加载中的Lottie动画
    HLLUBroadCastEvent["showLoadingLottieAniamtion"] = "kNotificationshowLoadingLottieAniamtion";
    // 4.隐藏Lottie动画
    HLLUBroadCastEvent["hideLoadingLottieAniamtion"] = "kNotificationHideLoadingLottieAniamtion";
    // 5.监听用户昵称修改的通知
    HLLUBroadCastEvent["kNotificationChangeUserNickName"] = "kNotificationChangeUserNickName";
    // 6.刷新设置红点
    HLLUBroadCastEvent["kRefreshSettingRetDot"] = "kRefreshSettingRetDot";
})(HLLUBroadCastEvent || (HLLUBroadCastEvent = {}));
var HLLUNavigatorEventBridge;
(function (HLLUNavigatorEventBridge) {
    HLLUNavigatorEventBridge["setBarHidden"] = "setBarHidden";
})(HLLUNavigatorEventBridge || (HLLUNavigatorEventBridge = {}));

var HLLHTTPMethod;
(function (HLLHTTPMethod) {
    HLLHTTPMethod["GET"] = "GET";
    HLLHTTPMethod["POST"] = "POST";
})(HLLHTTPMethod || (HLLHTTPMethod = {}));
/**
 * 请求端上接口
 * @param method 接口名
 * @param params 接口参数
 * @param succuss 请求成功回调
 * @param failure 请求失败回调
*/
function fetch(parameter, succuss = null, failure = null, type = HLLHTTPMethod.GET) {
    if (parameter.showloading) {
        HLLUBridge.sendModalNativeEvent(HLLUModalEventBridge.showLoading);
    }
    HLLUBridge.sendNetRequestEvent(type, parameter.method, parameter.params, (response) => {
        if (parameter.showloading) {
            HLLUBridge.sendModalNativeEvent(HLLUModalEventBridge.dismissLoading);
        }
        if (succuss) {
            succuss(response);
        }
    }, (err) => {
        if (parameter.showloading) {
            HLLUBridge.sendModalNativeEvent(HLLUModalEventBridge.dismissLoading);
        }
        if (failure) {
            failure(err);
        }
    });
}

class HLLUTools {
    /**
    * 判断字符串是否为JSON字符串
    */
    static isValidJsonString(str) {
        if (typeof str !== 'string') {
            return false;
        }
        try {
            const parsed = JSON.parse(str);
            return parsed && typeof parsed === 'object';
        }
        catch (e) {
            return false;
        }
    }
    /**
     * 判断对象的key是否为空
     * @param obj
     * @param key
     * @returns {boolean}
     */
    static isEmpty(obj, key) {
        if (!this.contain(obj, key)) {
            return true;
        }
        if (obj[key].length > 0) {
            return false;
        }
        return true;
    }
    /**
     * 判断对象是否包含key
     * @param {Object} obj
     * @param {string} key
     * @returns {boolean}
     */
    static contain(obj, key) {
        if (!this.isObject(obj)) {
            return false;
        }
        if (Object.prototype.toString.call(obj[key]) === '[object Undefined]') {
            return false;
        }
        return true;
    }
    /**
     * 判断是否数组
     * @param val
     * @returns {boolean}
     */
    static isArray(val) {
        if (Object.prototype.toString.call(val) === '[object Array]') {
            return true;
        }
        return false;
    }
    /**
     * 判断是否字符串
     * @param val
     * @returns {boolean}
     */
    static isString(val) {
        if (Object.prototype.toString.call(val) === '[object String]') {
            return true;
        }
        return false;
    }
    /**
     * 判断是否数字[注意，NaN也为数字]
     * @param val
     * @returns {boolean}
     */
    static isNumber(val) {
        if (Object.prototype.toString.call(val) === '[object Number]') {
            return true;
        }
        return false;
    }
    /**
     * 判断是否boolean类型
     * @param val
     * @returns {boolean}
     */
    static isBoolean(val) {
        if (Object.prototype.toString.call(val) === '[object Boolean]') {
            return true;
        }
        return false;
    }
    static isFunction(val) {
        if (Object.prototype.toString.call(val) === '[object Function]') {
            return true;
        }
        return false;
    }
    /**
     * 判断是否对象
     * @param val
     * @returns {boolean}
     */
    static isObject(val) {
        if (Object.prototype.toString.call(val) === '[object Object]') {
            return true;
        }
        return false;
    }
    static getRandomColor() {
        var letters = '0123456789ABCDEF';
        var color = '#';
        for (var i = 0; i < 6; i++) {
            color += letters[Math.floor(Math.random() * 16)];
        }
        return color;
    }
    static $string(value) {
        if (typeof value == 'undefined' || value === null) {
            return "";
        }
        return value.toString();
    }
    static $number(value) {
        value = Number(value);
        if ((value + '') == 'NaN') {
            return 0;
        }
        return value;
    }
    static $money(value) {
        value = Number(value);
        if ((value + '') == 'NaN') {
            return "";
        }
        value = value / 100;
        let formatted = value.toFixed(2);
        formatted = formatted.replace(/\.0+$/, "");
        formatted = formatted.replace(/(\.\d+?)0+$/, "$1");
        return formatted;
    }
    static formatDateToChinese(dateStr) {
        try {
            const yearMonthDayPattern = /^(\d{4})[-/.](\d{2})[-/.](\d{2})$/;
            const yearMonthPattern = /^(\d{4})[-/.](\d{2})$/;
            if (yearMonthDayPattern.test(dateStr)) {
                const [_, year, month, day] = dateStr.match(yearMonthDayPattern);
                return `${year}年${month}月${day}日`;
            }
            else if (yearMonthPattern.test(dateStr)) {
                const [_, year, month] = dateStr.match(yearMonthPattern);
                return `${year}年${month}月`;
            }
            else {
                throw new Error('输入的日期格式不正确，应该是"YYYY-MM"或"YYYY-MM-DD"格式的字符串');
            }
        }
        catch (error) {
            return dateStr;
        }
    }
    // 格式化手机号，中间四位用星号替换
    static formatMobile(mobile) {
        if (mobile.length === 11) {
            return mobile.replace(/(\d{3})\d{4}(\d{4})/, '$1****$2');
        }
        else {
            return mobile;
        }
    }
    static color16() {
        var r = Math.floor(Math.random() * 256);
        var g = Math.floor(Math.random() * 256);
        var b = Math.floor(Math.random() * 256);
        var color = '#' + r.toString(16) + g.toString(16) + b.toString(16);
        return color;
    }
    static getFrameCity() {
        let finale_frame_city = "";
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getCityInfo, {}, (info) => {
            if (this.isObject(info)) {
                let { frame_city } = info;
                finale_frame_city = this.$string(frame_city);
            }
        });
        return finale_frame_city;
    }
    static getUserFid() {
        let user_fid = "";
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserFid, {}, (info) => {
            if (this.isObject(info)) {
                let { user_fid } = info;
                user_fid = this.$string(user_fid);
            }
        });
        return user_fid;
    }
    static getDeviceInfo(callback) {
        HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.getDeviceInfo, {}, (info) => {
            if (this.isObject(info)) {
                if (callback) {
                    callback(info);
                }
            }
        });
    }
}

/**
 * Get bundle path
 *
 * @export
 * @param {String} className
 * @param {String} resource
 * @return {*}  {string}
 */
function bundlePath(className, resource) {
    const wrappedParam = { "class": className, "resource": resource };
    let url = '';
    wrappedParam.success = (response) => {
        var _a;
        url = (_a = response["url"]) !== null && _a !== void 0 ? _a : '';
    };
    context.sendMessage("bundle", "bundlePath", wrappedParam);
    return url;
}

/**
 * request function, which provides native network requests
 *
 * @memberOfBridge network
 *
 * @param param
 * @param param.params Parameters required in a request. You can put any data required by native side.
 *                     The definitions of fields in the params need to be aligned on both iOS and Android.
 * @param param.usedCache Whether to use cache or not.
 * @param param.method request method  POST or GET
 * @param param.onSuccess callback called when the request succeeds
 * @param param.onFail callback called when the request fails
 */
var RequestMethod;
(function (RequestMethod) {
    RequestMethod["Post"] = "POST";
    RequestMethod["Get"] = "GET";
})(RequestMethod || (RequestMethod = {}));

/**
 * This function deletes the specified locally stored value
 *
 * @memberOfBridge storage
 *
 * @param {string} key The key of the to-be-deleted value
 */
function remove(key) {
    context.sendMessage("storage", "remove", { key });
}
/**
 * The function to retrieve locally stored data
 *
 * @memberOfBridge storage
 *
 * @param {string} key The key of the target value
 *
 * @returns {string} the value corresponding to the key
 */
function retrieve(key) {
    return context.sendMessage("storage", "retrieve", { key });
}
/**
 * The function to write/store to local storage, which provids the ability to
 * persist the data into the local file system
 *
 * @memberOfBridge storage
 *
 * @param {string} key
 * @param {string} value
 * @returns {boolean} whether the store action succeeded
 */
function store(key, value) {
    return context.sendMessage("storage", "store", { key, value });
}

/**
 * Broadcast channel
 *
 * @Android availble in Android
 * @iOS not availble in iOS
 */
var BroadcastChannel;
(function (BroadcastChannel) {
    /**
     * support the LocalBroadcastManager channel in the bundle
     */
    BroadcastChannel[BroadcastChannel["LOCAL"] = 0] = "LOCAL";
    /**
     * By using SYSTEM, data will broadcasted directly through the system broadcast channel
     */
    BroadcastChannel[BroadcastChannel["SYSTEM"] = 1] = "SYSTEM";
    /**
     * Support both local and sysyem channel
     */
    BroadcastChannel[BroadcastChannel["ALL"] = 2] = "ALL";
})(BroadcastChannel || (BroadcastChannel = {}));
/**
 * Send broadcast
 * The broadcast can be received by the callback passed into the subscribe function,
 * or it can be received by the native receiver.
 *
 * @memberOfBridge broadcast
 *
 * @param action broadcast name
 * @param config
 * @param config.info Additional information carried by the broadcast
 * @param config.channel Android only, LOCAL by default
 */
function publish(action, config) {
    const arg = { action };
    if (config) {
        if (config.info) {
            arg.info = config.info;
        }
        if (typeof config.channel !== "undefined") {
            arg.channel = config.channel;
        }
    }
    context.sendMessage("broadcast", "publish", arg);
}
/**
 * Subscribe to a broadcast. The broadcast can be a native broadcast or a broadcast sent by the publish function
 *
 * @memberOfBridge broadcast
 * @iOS Send through NSNotificationCenter
 * @Android Send through LocalBroadcastManager OR context.sendBroadcast OR both of them,
 *          which is controlled by the channel parameter in config. And the default value is ALL.
 *
 * @param action The name of the broadcast to be subscribed
 * @param f broadcast callback
 * @param config
 * @param config.channel
 *
 * @returns handleId - Will be passed into unsubscribe function as a parameter
 */
function subscribe(action, f, config) {
    const wrappedParam = {};
    wrappedParam.action = action;
    wrappedParam.handle = (data) => {
        if (data && data.info) {
            f(data.info);
        }
        else {
            f();
        }
    };
    if (config) {
        if (typeof config.channel !== "undefined") {
            wrappedParam.channel = config.channel;
        }
    }
    return context.sendMessage("broadcast", "subscribe", wrappedParam);
}

const HLLUIHelper = {
    createLabel(text, color, font, textAlign = HLLUTextAlignment.left) {
        let textView = new paladin.TextView;
        textView.text = text;
        textView.textColor = color;
        textView.textAlignment = textAlign;
        textView.textSize = font.fontSize;
        textView.fontStyle = font.fontStyle;
        textView.fontWeight = Number(font.fontWeight);
        return textView;
    }
};

class HLLUFont {
    set fontSize(fontSize) {
        this._fontSize = fontSize;
    }
    get fontSize() {
        return this._fontSize;
    }
    set fontWeight(fontWeight) {
        this._fontWeight = fontWeight;
    }
    get fontWeight() {
        return this._fontWeight;
    }
    set fontStyle(fontStyle) {
        this._fontStyle = fontStyle;
    }
    get fontStyle() {
        return this._fontStyle;
    }
    static fontWithParams(fontSize, fontWeight = HLLUFontWeight.Regular, fontStyle = HLLUFontStyle.none) {
        let font = new HLLUFont;
        font.fontSize = fontSize;
        font.fontWeight = fontWeight;
        font.fontStyle = fontStyle;
        return font;
    }
}

class HLLUColor {
    static get white() {
        return HLLUColor.colorWithHex(HLLUColorValue.white);
    }
    static get black() {
        return HLLUColor.colorWithHex(HLLUColorValue.black);
    }
    static colorWithHex(hex, alpha = HLLUAlpha.p100) {
        let color = "";
        if (hex.startsWith("#") && hex.length == 7) {
            let temp = hex.split("#");
            if (temp.length == 2) {
                color = "#" + alpha + temp[1];
            }
        }
        return color;
    }
}

class HLLUCompleteOrderRateModel {
    constructor() {
        this.rate = "";
        this.show_name = "";
        this.url = "";
    }
    static createCompleteOrderRateModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { rate, show_name, url } = info;
            model.rate = HLLUTools.$string(rate);
            model.show_name = HLLUTools.$string(show_name);
            model.url = HLLUTools.$string(url);
        }
        return model;
    }
}

class HLLUPersonalAuthModel {
    constructor() {
        this.personal_auth_status = 0;
        this.personal_auth_url = '';
        this.personal_auth_text = '';
        this.personal_auth_level = 0;
    }
    static createPersonalAuthModel(info) {
        const model = new this;
        if (HLLUTools.isObject(info)) {
            let { personal_auth_status, personal_auth_url, personal_auth_text, personal_auth_level } = info;
            model.personal_auth_status = HLLUTools.$number(personal_auth_status);
            model.personal_auth_url = HLLUTools.$string(personal_auth_url);
            model.personal_auth_text = HLLUTools.$string(personal_auth_text);
            model.personal_auth_level = HLLUTools.$number(personal_auth_level);
        }
        return model;
    }
}

class HLLURatingModel {
    constructor() {
        this.rating = 0; // 评分
        this.is_show = 0;
        this.next_type = 0; // 1 正常页 2 假页面 3 暂无数据页（2-假评分的逻辑已经下线 2024.11.8）
        this.score = 0;
    }
    static createRatingModel(info) {
        let model = new HLLURatingModel();
        if (HLLUTools.isObject(info)) {
            model.rating = HLLUTools.$number(info.rating);
            model.is_show = HLLUTools.$number(info.is_show);
            model.next_type = HLLUTools.$number(info.next_type);
            model.score = HLLUTools.$number(info.score);
        }
        return model;
    }
}

class HLLUUserSettingModel {
    constructor() {
        this.recommend_switch = 0;
        this.msg_notice_switch = 0;
        this.communicate_privi_switch = "0";
        this.activity_privi_switch = 0;
        this.activity_banner_switch = 0;
    }
    static createSettingInfoModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { recommend_switch, msg_notice_switch, communicate_privi_switch, activity_privi_switch, activity_banner_switch } = info;
            model.recommend_switch = HLLUTools.$number(recommend_switch);
            model.msg_notice_switch = HLLUTools.$number(msg_notice_switch);
            model.communicate_privi_switch = HLLUTools.$string(communicate_privi_switch);
            model.activity_privi_switch = HLLUTools.$number(activity_privi_switch);
            model.activity_banner_switch = HLLUTools.$number(activity_banner_switch);
        }
        return model;
    }
}

class HLLUUserInfoModel {
    constructor() {
        this.phone_no = "";
        this.avatar = "";
        this.nickname = "";
        this.member_icon = "";
        this.comment_star_new = new HLLURatingModel();
        this.complete_order_rate = new HLLUCompleteOrderRateModel();
        this.auth_strategy_info = new HLLUPersonalAuthModel();
        this.switch_setting = new HLLUUserSettingModel();
    }
    static createDriverInfoModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { phone_no, avatar, nickname, member_icon, comment_star_new, complete_order_rate, auth_strategy_info, switch_setting } = info;
            model.phone_no = HLLUTools.$string(phone_no);
            model.avatar = HLLUTools.$string(avatar);
            model.nickname = HLLUTools.$string(nickname);
            model.member_icon = HLLUTools.$string(member_icon);
            model.comment_star_new = HLLURatingModel.createRatingModel(comment_star_new);
            model.complete_order_rate = HLLUCompleteOrderRateModel.createCompleteOrderRateModel(complete_order_rate);
            model.auth_strategy_info = HLLUPersonalAuthModel.createPersonalAuthModel(auth_strategy_info);
            model.switch_setting = HLLUUserSettingModel.createSettingInfoModel(switch_setting);
        }
        return model;
    }
}

class HLLUInformationLargeView extends paladin.View {
    constructor() {
        super();
        this.isLogined = false;
        this.userInfoModel = new HLLUUserInfoModel();
        this.showSettingRedDot = false;
        this.backgroundColor = HLLUColorValue.f3f4f5;
    }
    static createInformationView(size) {
        let view = new this;
        view.size = size;
        return view;
    }
    layout(tabbarHeight) {
        let avatarImageViewBgView = this.createHeaderAvatarImageView(tabbarHeight);
        HLLUBridge.sendTrackSensorEvent({
            name: "personal_center_NEW",
            properties: {
                event_type: "曝光",
                frame_city: HLLUTools.getFrameCity(),
                button_type: "个人头像区域",
                module_type: "个人信息区域"
            },
            needControl: true
        });
        avatarImageViewBgView.onClick = () => {
            HLLUBridge.sendTrackSensorEvent({
                name: "personal_center_NEW",
                properties: {
                    event_type: "点击",
                    frame_city: HLLUTools.getFrameCity(),
                    button_type: "个人头像区域",
                    module_type: "个人信息区域"
                }
            });
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickAvatarOrLoginEvent);
        };
        this.addSubView(avatarImageViewBgView);
        let { avatar } = this.userInfoModel;
        if (this.isLogined) {
            // 展示登录成功的UI
            if (avatar && avatar.length > 0 && this.avatarImageView) {
                this.avatarImageView.image = "";
                this.avatarImageView.imageUrl = avatar;
            }
            let nickNameLabel = this.createNickNameLabel(tabbarHeight);
            nickNameLabel.left = avatarImageViewBgView.right + 10;
            this.addSubView(nickNameLabel);
            // 展示企业认证模块 
            let list = this.createCertificationView(tabbarHeight, nickNameLabel.right);
            if (HLLUTools.isArray(list)) {
                if (list.length > 0) {
                    let firstView = list[0];
                    this.addSubView(firstView);
                }
                if (list.length > 1) {
                    let secondView = list[1];
                    this.addSubView(secondView);
                }
            }
            // 展示星级评分模块 
            let ratingView = this.createRatingView(nickNameLabel.bottom);
            this.addSubView(ratingView);
            // 展示完单率模块
            let completeOrderRateView = this.createCompleteOrderRateView(ratingView.right, ratingView.top);
            if (completeOrderRateView) {
                this.addSubView(completeOrderRateView);
            }
        }
        else {
            // 展示未登录
            let unloginTitleLabel = this.createUnloginedTitleLabel();
            unloginTitleLabel.centerY = avatarImageViewBgView.centerY;
            unloginTitleLabel.left = avatarImageViewBgView.right + 10;
            this.addSubView(unloginTitleLabel);
        }
        // 展示设置按钮
        let settingImageView = this.createSettingImageView(tabbarHeight);
        this.addSubView(settingImageView);
        // 扫一扫按钮
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getHomepageChangeModeCount, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let count = HLLUTools.$number(info.homepage_change_mode_count);
                if (this.isLogined && count > 1) {
                    HLLUBridge.sendTrackSensorEvent({
                        name: "personal_center_NEW",
                        properties: {
                            event_type: "曝光",
                            frame_city: HLLUTools.getFrameCity(),
                            button_type: "扫一扫",
                            module_type: "个人信息区域"
                        },
                        needControl: true
                    });
                    let scanImageView = this.createScanImageView(settingImageView);
                    this.addSubView(scanImageView);
                }
            }
        });
        // 展示小红点
        if (this.showSettingRedDot) {
            let redDotView = this.createRedDotView(settingImageView.top - 4, settingImageView.right);
            this.addSubView(redDotView);
        }
    }
    createScanImageView(settingImageView) {
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_scan_new;
        imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imageView.width = 28;
        imageView.height = 28;
        imageView.top = settingImageView.top;
        imageView.right = this.width - 24 - imageView.width;
        imageView.onClick = () => {
            if (this.clickScanEvent) {
                this.clickScanEvent({
                    x: imageView.left,
                    y: imageView.top
                });
            }
        };
        return imageView;
    }
    // 企业认证模块
    createCertificationView(top, left) {
        let list = [];
        let { personal_auth_text, personal_auth_level, personal_auth_url, personal_auth_status } = this.userInfoModel.auth_strategy_info;
        if (personal_auth_text && personal_auth_text.length > 0 && personal_auth_url && personal_auth_url.length > 0) {
            let showRedDot = personal_auth_status != 1 || (personal_auth_status == 1 && personal_auth_level != 1);
            let view = new paladin.View;
            view.left = left + 6;
            view.top = top + 21.5;
            view.borderColor = HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p12);
            view.borderWidth = 0.5;
            view.height = 19;
            view.width = 100;
            view.cornerRadius = 4;
            let label = HLLUIHelper.createLabel(personal_auth_text, HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p65), HLLUFont.fontWithParams(11));
            label.sizeToFit();
            label.top = 2;
            label.left = 6;
            label.height = 15;
            view.addSubView(label);
            // 箭头
            let imageView = new paladin.ImageView;
            imageView.image = HLLUImageNames.ic_auth_arrow;
            imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
            imageView.width = 10;
            imageView.height = 11;
            imageView.centerY = label.centerY;
            imageView.left = label.right;
            view.addSubView(imageView);
            view.width = imageView.right + 4;
            list.push(view);
            view.onClick = () => {
                if (personal_auth_url && personal_auth_url.length > 0) {
                    HLLUBridge.sendTrackSensorEvent({
                        name: "personal_center_NEW",
                        properties: {
                            event_type: "点击",
                            frame_city: HLLUTools.getFrameCity(),
                            button_type: "企业认证",
                            module_type: "个人信息区域"
                        }
                    });
                    HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickEnterpriseAuthEvent, {
                        personal_auth_url
                    });
                }
            };
            // 展示企业认证小红点
            let redDotView = null;
            if (showRedDot) {
                redDotView = new paladin.View;
                redDotView.width = 8;
                redDotView.height = 8;
                redDotView.top = view.top - 4;
                redDotView.right = view.right + 4;
                redDotView.cornerRadius = 4;
                redDotView.backgroundColor = HLLUColorValue.FF3B30;
                list.push(redDotView);
            }
        }
        HLLUBridge.sendTrackSensorEvent({
            name: "personal_center_NEW",
            properties: {
                event_type: "曝光",
                frame_city: HLLUTools.getFrameCity(),
                button_type: "企业认证",
                module_type: "个人信息区域"
            },
            needControl: true
        });
        return list;
    }
    // 小红点
    createRedDotView(top, right) {
        let view = new paladin.View;
        view.width = 8;
        view.height = 8;
        view.top = top;
        view.right = right;
        view.cornerRadius = 4;
        view.backgroundColor = HLLUColorValue.FF3B30;
        return view;
    }
    // 完单率模块
    createCompleteOrderRateView(left, top) {
        // 完单率
        let { rate, show_name, url } = this.userInfoModel.complete_order_rate;
        if (!show_name || show_name.length == 0) {
            return null;
        }
        let view = new paladin.View;
        view.backgroundColor = HLLUColor.colorWithHex(HLLUColorValue.FFBA15, HLLUAlpha.p20);
        view.left = left + 6;
        view.top = top;
        view.height = 19;
        view.cornerRadius = 4;
        let label = HLLUIHelper.createLabel(`${show_name} ${rate}`, HLLUColorValue.B2B08, HLLUFont.fontWithParams(11));
        label.sizeToFit();
        label.top = 2;
        label.left = 6;
        label.height = 15;
        view.addSubView(label);
        // 箭头
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_evaluate_score;
        imageView.bundle = bundlePath(HLLUPersonalCenterImageBundle.path, HLLUPersonalCenterImageBundle.name);
        imageView.width = 10;
        imageView.height = 11;
        imageView.centerY = label.centerY;
        imageView.left = label.right;
        view.addSubView(imageView);
        view.width = imageView.right + 4;
        view.onClick = () => {
            let complete_order_rate_url = this.userInfoModel.complete_order_rate.url;
            if (complete_order_rate_url && complete_order_rate_url.length > 0) {
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickUserOrderCompleteEvent, {
                    complete_order_rate_url
                });
            }
            HLLUBridge.sendTrackSensorEvent({
                name: "complate_rate_click",
                properties: {
                    frame_city: HLLUTools.getFrameCity(),
                    page_from: "我的",
                    complate_score: this.userInfoModel.complete_order_rate.rate,
                    user_fid: HLLUTools.getUserFid()
                }
            });
            HLLUBridge.sendTrackSensorEvent({
                name: "personal_center_NEW",
                properties: {
                    event_type: "点击",
                    frame_city: HLLUTools.getFrameCity(),
                    button_type: "完单率",
                    module_type: "个人信息区域"
                }
            });
        };
        HLLUBridge.sendTrackSensorEvent({
            name: "complate_rate_expo",
            properties: {
                frame_city: HLLUTools.getFrameCity(),
                page_from: "我的",
                complate_score: this.userInfoModel.complete_order_rate.rate,
                user_fid: HLLUTools.getUserFid()
            },
            needControl: true
        });
        HLLUBridge.sendTrackSensorEvent({
            name: "personal_center_NEW",
            properties: {
                event_type: "曝光",
                frame_city: HLLUTools.getFrameCity(),
                button_type: "完单率",
                module_type: "个人信息区域"
            },
            needControl: true
        });
        return view;
    }
    // 星级评分模块
    createRatingView(top) {
        let view = new paladin.View;
        view.backgroundColor = HLLUColor.colorWithHex(HLLUColorValue.FFBA15, HLLUAlpha.p20);
        view.left = 74;
        view.top = top + 6;
        view.height = 19;
        view.cornerRadius = 4;
        // 星级评分
        let text = "暂无星级评分";
        let { score, rating } = this.userInfoModel.comment_star_new;
        if (score > 0) {
            text = "星级评分 " + score.toFixed(1);
        }
        let label = HLLUIHelper.createLabel(text, HLLUColorValue.B2B08, HLLUFont.fontWithParams(11));
        label.sizeToFit();
        label.top = 2;
        label.left = 6;
        label.height = 15;
        view.addSubView(label);
        // 箭头
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_evaluate_score;
        imageView.bundle = bundlePath(HLLUPersonalCenterImageBundle.path, HLLUPersonalCenterImageBundle.name);
        imageView.width = 10;
        imageView.height = 11;
        imageView.centerY = label.centerY;
        imageView.left = label.right;
        view.addSubView(imageView);
        view.width = imageView.right + 4;
        let grade_type = "有评分";
        if (rating == 0) {
            grade_type = "暂无评分";
        }
        HLLUBridge.sendTrackSensorEvent({
            name: "grade_expo",
            properties: {
                frame_city: HLLUTools.getFrameCity(),
                page_from: "我的",
                grade_type,
                score: rating == 0 ? "0" : rating.toFixed(1),
                user_fid: HLLUTools.getUserFid()
            },
            needControl: true
        });
        HLLUBridge.sendTrackSensorEvent({
            name: "personal_center_NEW",
            properties: {
                event_type: "曝光",
                frame_city: HLLUTools.getFrameCity(),
                button_type: "星级评分",
                module_type: "个人信息区域",
            },
            needControl: true
        });
        view.onClick = () => {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickStarRatingEvent);
            // 点击埋点
            let grade_type = "有评分";
            if (rating == 0) {
                grade_type = "暂无评分";
            }
            HLLUBridge.sendTrackSensorEvent({
                name: "grade_ent_click",
                properties: {
                    frame_city: HLLUTools.getFrameCity(),
                    page_from: "我的",
                    grade_type,
                    score: rating == 0 ? "0" : rating.toFixed(1),
                    user_fid: HLLUTools.getUserFid()
                }
            });
            HLLUBridge.sendTrackSensorEvent({
                name: "personal_center_NEW",
                properties: {
                    event_type: "点击",
                    frame_city: HLLUTools.getFrameCity(),
                    button_type: "星级评分",
                    module_type: "个人信息区域"
                }
            });
        };
        return view;
    }
    createNickNameLabel(top) {
        let { nickname } = this.userInfoModel;
        if (!nickname || nickname.length == 0) {
            HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserPhone, {}, (info) => {
                if (HLLUTools.isObject(info)) {
                    let { user_phone } = info;
                    nickname = HLLUTools.formatMobile(user_phone);
                }
            });
        }
        else {
            // 昵称超过6个字后，剩余用“...”填充
            if (nickname.length > 5) {
                nickname = nickname.substring(0, 5) + "...";
            }
        }
        let label = HLLUIHelper.createLabel(nickname, HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p85), HLLUFont.fontWithParams(18, HLLUFontWeight.Bold, HLLUFontStyle.bold));
        label.sizeToFit();
        label.top = top + 20;
        label.left = 72;
        label.right = this.width - 12;
        label.height = 22;
        label.onClick = () => {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickAvatarOrLoginEvent);
        };
        return label;
    }
    createSettingImageView(top) {
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_setting_new;
        imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imageView.width = 28;
        imageView.height = 28;
        imageView.top = 20 + top;
        imageView.right = this.width - 12;
        imageView.onClick = () => {
            if (this.clickSettingEvent) {
                HLLUBridge.sendTrackSensorEvent({
                    name: "personal_center_NEW",
                    properties: {
                        event_type: "点击",
                        frame_city: HLLUTools.getFrameCity(),
                        button_type: "右上角更多设置",
                        module_type: "个人信息区域"
                    }
                });
                this.clickSettingEvent();
            }
        };
        HLLUBridge.sendTrackSensorEvent({
            name: "personal_center_NEW",
            properties: {
                event_type: "曝光",
                frame_city: HLLUTools.getFrameCity(),
                button_type: "右上角更多设置",
                module_type: "个人信息区域"
            },
            needControl: true
        });
        return imageView;
    }
    createHeaderAvatarImageView(top) {
        let view = new paladin.View;
        view.width = 51;
        view.height = 51;
        view.cornerRadius = 25.5;
        view.backgroundColor = HLLUColorValue.white;
        view.top = 20 + top;
        view.left = 16;
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_default_avatar;
        imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imageView.left = 1.5;
        imageView.top = 1.5;
        imageView.width = 48;
        imageView.height = 48;
        imageView.cornerRadius = 24;
        this.avatarImageView = imageView;
        view.addSubView(imageView);
        return view;
    }
    createUnloginedTitleLabel() {
        let label = HLLUIHelper.createLabel("立即登录", HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p85), HLLUFont.fontWithParams(18));
        label.sizeToFit();
        label.onClick = () => {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickAvatarOrLoginEvent);
        };
        return label;
    }
}

class HLLUInformationSmallView extends paladin.View {
    constructor() {
        super();
        this.isLogined = false;
        this.userInfoModel = new HLLUUserInfoModel();
        this.showSettingRedDot = false;
        this.backgroundColor = HLLUColorValue.f3f4f5;
    }
    static createInformationView(size) {
        let view = new this;
        view.size = size;
        return view;
    }
    layout(tabbarHeight) {
        let avatarImageViewBgView = this.createHeaderAvatarImageView(tabbarHeight);
        avatarImageViewBgView.onClick = () => {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickAvatarOrLoginEvent);
        };
        this.addSubView(avatarImageViewBgView);
        let { avatar } = this.userInfoModel;
        if (this.isLogined) {
            // 展示登录成功的UI
            if (avatar && avatar.length > 0 && this.avatarImageView) {
                this.avatarImageView.image = "";
                this.avatarImageView.imageUrl = avatar;
            }
            // 展示登录成功的UI
            let nickNameLabel = this.createNickNameLabel();
            nickNameLabel.centerY = avatarImageViewBgView.centerY;
            nickNameLabel.left = avatarImageViewBgView.right + 10;
            this.addSubView(nickNameLabel);
        }
        else {
            // 展示未登录
            let unloginTitleLabel = this.createUnloginedTitleLabel();
            unloginTitleLabel.centerY = avatarImageViewBgView.centerY;
            unloginTitleLabel.left = avatarImageViewBgView.right + 10;
            this.addSubView(unloginTitleLabel);
        }
        // 展示设置按钮
        let settingImageView = this.createSettingImageView(tabbarHeight);
        this.addSubView(settingImageView);
        // 展示小红点
        if (this.showSettingRedDot) {
            let redDotView = this.createRedDotView(settingImageView.top - 4, settingImageView.right);
            this.addSubView(redDotView);
        }
        // 扫一扫按钮
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getHomepageChangeModeCount, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let count = HLLUTools.$number(info.homepage_change_mode_count);
                if (this.isLogined && count > 1) {
                    let scanImageView = this.createScanImageView(settingImageView);
                    this.addSubView(scanImageView);
                }
            }
        });
    }
    createScanImageView(settingImageView) {
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_scan_new;
        imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imageView.width = 28;
        imageView.height = 28;
        imageView.top = settingImageView.top;
        imageView.right = this.width - 24 - imageView.width;
        imageView.onClick = () => {
            if (this.clickScanEvent) {
                this.clickScanEvent({
                    x: imageView.left,
                    y: imageView.top
                });
            }
        };
        return imageView;
    }
    // 小红点
    createRedDotView(top, right) {
        let view = new paladin.View;
        view.width = 8;
        view.height = 8;
        view.top = top;
        view.right = right;
        view.cornerRadius = 4;
        view.backgroundColor = HLLUColorValue.FF3B30;
        return view;
    }
    createNickNameLabel() {
        let { nickname } = this.userInfoModel;
        if (!nickname || nickname.length == 0) {
            HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserPhone, {}, (info) => {
                if (HLLUTools.isObject(info)) {
                    let { user_phone } = info;
                    nickname = HLLUTools.formatMobile(user_phone);
                }
            });
        }
        else {
            // 昵称超过6个字后，剩余用“...”填充
            if (nickname.length > 6) {
                nickname = nickname.substring(0, 6) + "...";
            }
        }
        let label = HLLUIHelper.createLabel(nickname, HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p85), HLLUFont.fontWithParams(16, HLLUFontWeight.Bold, HLLUFontStyle.bold));
        label.sizeToFit();
        label.onClick = () => {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickAvatarOrLoginEvent);
        };
        return label;
    }
    createSettingImageView(top) {
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_setting_new;
        imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imageView.width = 28;
        imageView.height = 28;
        imageView.top = 8 + top;
        imageView.right = this.width - 12;
        imageView.onClick = () => {
            if (this.clickSettingEvent) {
                this.clickSettingEvent();
            }
        };
        return imageView;
    }
    createHeaderAvatarImageView(top) {
        let view = new paladin.View;
        view.width = 27;
        view.height = 27;
        view.cornerRadius = 13.5;
        view.backgroundColor = HLLUColorValue.white;
        view.top = 10 + top;
        view.left = 16;
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_default_avatar;
        imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imageView.width = 24;
        imageView.height = 24;
        imageView.cornerRadius = 12;
        imageView.left = 1.5;
        imageView.top = 1.5;
        this.avatarImageView = imageView;
        view.addSubView(imageView);
        return view;
    }
    createUnloginedTitleLabel() {
        let label = HLLUIHelper.createLabel("立即登录", HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p85), HLLUFont.fontWithParams(16));
        label.sizeToFit();
        label.onClick = () => {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickAvatarOrLoginEvent);
        };
        return label;
    }
}

const requestPersonalCenterDataInMock = (item, succuss = null, failure = null) => {
    {
        fetch(item, succuss, failure);
    }
};

class HLLUPopverView extends paladin.View {
    constructor() {
        super(...arguments);
        this.options = {
            titles: [],
            imageNames: []
        };
    }
    static createPopverView(options) {
        let view = new this;
        view.width = 110;
        view.options = options;
        view.layout();
        return view;
    }
    layout() {
        // 箭头
        let arrowImageView = this.createArrowImageView();
        this.addSubView(arrowImageView);
        // 内容区域
        let contentView = this.createContentBgView(arrowImageView.bottom);
        this.addSubView(contentView);
        this.height = contentView.bottom;
        // 标题区域
    }
    createContentBgView(top) {
        let view = new paladin.View;
        view.backgroundColor = HLLUColorValue.C222836;
        view.width = this.width;
        view.height = 100;
        view.cornerRadius = 8;
        view.top = top;
        // 创建内容
        let lastView;
        for (let i = 0; i < this.options.titles.length; i++) {
            let title = this.options.titles[i];
            let imageName = this.options.imageNames[i];
            let itemView = this.createItemView(i, title, imageName);
            if (i == 0) {
                itemView.top = 0;
            }
            else {
                itemView.top = lastView.bottom;
            }
            itemView.left = 0;
            itemView.width = this.width;
            itemView.height = 48;
            lastView = itemView;
            view.addSubView(itemView);
            itemView.onClick = () => {
                if (this.options.clickEvent) {
                    this.options.clickEvent(i);
                }
            };
        }
        view.height = lastView.bottom;
        return view;
    }
    createItemView(index, title, imageName) {
        let view = new paladin.View;
        view.backgroundColor = HLLUColorValue.C222836;
        view.width = this.width;
        view.height = 48;
        view.cornerRadius = 8;
        let imageView = new paladin.ImageView;
        imageView.image = imageName;
        imageView.bundle = bundlePath(HLLUPersonalCenterImageBundle.path, HLLUPersonalCenterImageBundle.name);
        imageView.width = 24;
        imageView.height = 24;
        imageView.centerY = view.centerY;
        imageView.left = 12;
        view.addSubView(imageView);
        let label = HLLUIHelper.createLabel(title, HLLUColorValue.white, HLLUFont.fontWithParams(14), HLLUTextAlignment.center);
        label.sizeToFit();
        label.width = 60;
        label.centerY = view.centerY;
        label.left = imageView.right + 6;
        label.height = 15;
        view.addSubView(label);
        if (index != 0) {
            let lineView = new paladin.View;
            lineView.backgroundColor = HLLUColor.colorWithHex(HLLUColorValue.white, HLLUAlpha.p25);
            lineView.left = 12;
            lineView.width = view.width - 24;
            lineView.height = 0.5;
            view.addSubView(lineView);
        }
        return view;
    }
    createArrowImageView() {
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_trangle_top;
        imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imageView.width = 12;
        imageView.height = 7;
        imageView.right = this.width - 18;
        return imageView;
    }
}

class HLLUModuleConfigModel {
    constructor() {
        this.name = "";
        this.keyword = "";
        this.list = [];
    }
    static createModuleConfigModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { name, keyword } = info;
            model.name = HLLUTools.$string(name);
            model.keyword = HLLUTools.$string(keyword);
        }
        return model;
    }
}

class HLLUProfileCreditModel {
    constructor() {
        this.has_contorl = 0;
        this.has_cover = 0;
        this.has_warning = 0;
        this.data_version = "";
    }
    static createProfileCreditModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { has_contorl, has_cover, has_warning, data_version } = info;
            model.has_contorl = HLLUTools.$number(has_contorl);
            model.has_cover = HLLUTools.$number(has_cover);
            model.has_warning = HLLUTools.$number(has_warning);
            model.data_version = HLLUTools.$string(data_version);
        }
        return model;
    }
}

var HLLUCornerType;
(function (HLLUCornerType) {
    HLLUCornerType[HLLUCornerType["None"] = 0] = "None";
    HLLUCornerType[HLLUCornerType["Text"] = 1] = "Text";
    HLLUCornerType[HLLUCornerType["RedSpot"] = 2] = "RedSpot";
    HLLUCornerType[HLLUCornerType["NumberSpot"] = 3] = "NumberSpot";
})(HLLUCornerType || (HLLUCornerType = {}));
class HLLUPersonalListItemModel {
    constructor() {
        this.action_link = "";
        this.content = "";
        this.corner_bottom_title = "";
        this.corner_top_right = 0;
        this.corner_end_time = 0;
        this.corner_start_time = 0;
        this.corner_text = "";
        this.profile_credit_info = new HLLUProfileCreditModel;
        this.red_mark = 0;
        this.ad_id = "";
        this.corner_click_show = 0;
        this.ad_material_id = "";
        this.action_type = 0;
        this.can_share = 0;
        this.share_to = "";
        this.name = "";
        this.share_content = "";
        this.share_icon_url = "";
        this.share_url = "";
        this._su = "";
        this.wx_link_id = "";
        this.isAll = false;
        this.cornerType = HLLUCornerType.None;
        this.hasBeenClicked = false;
        this.shouldShowCorner = false;
        this.unreadMessageCount = 0;
        this.last_order_time = 0;
        this.ads_exposure_url = "";
        this.ads_log_commonparam = "";
        this.ads_hit_url = "";
        // 端上订单共享记录时间
        this.shareOrderLastTimeStamp = 0;
    }
    static createPersonalListItem(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { ad_material_id, ads_hit_url, ads_exposure_url, ads_log_commonparam, corner_click_show, ad_id, action_link, content, corner_bottom_title, corner_top_right, corner_end_time, corner_start_time, corner_text, profile_credit_info, red_mark, action_type, can_share, share_to, name, share_content, share_icon_url, share_url, _su, wx_link_id, unreadMessageCount } = info;
            model.action_link = HLLUTools.$string(action_link);
            model.content = HLLUTools.$string(content);
            model.name = HLLUTools.$string(name);
            model.corner_bottom_title = HLLUTools.$string(name);
            model.corner_top_right = HLLUTools.$number(corner_top_right);
            model.corner_end_time = HLLUTools.$number(corner_end_time);
            model.corner_start_time = HLLUTools.$number(corner_start_time);
            model.corner_text = HLLUTools.$string(corner_text);
            model.profile_credit_info = HLLUProfileCreditModel.createProfileCreditModel(profile_credit_info);
            model.red_mark = HLLUTools.$number(red_mark);
            model.ad_id = HLLUTools.$string(ad_id);
            model.corner_click_show = HLLUTools.$number(corner_click_show);
            model.action_type = HLLUTools.$number(action_type);
            model.can_share = HLLUTools.$number(can_share);
            model.share_to = HLLUTools.$string(share_to);
            model.share_content = HLLUTools.$string(share_content);
            model.share_icon_url = HLLUTools.$string(share_icon_url);
            model.share_url = HLLUTools.$string(share_url);
            model._su = HLLUTools.$string(_su);
            model.wx_link_id = HLLUTools.$string(wx_link_id);
            model.unreadMessageCount = HLLUTools.$number(unreadMessageCount);
            model.ads_exposure_url = HLLUTools.$string(ads_exposure_url);
            model.ads_log_commonparam = HLLUTools.$string(ads_log_commonparam);
            model.ads_hit_url = HLLUTools.$string(ads_hit_url);
            model.ad_material_id = HLLUTools.$string(ad_material_id);
        }
        return model;
    }
    static createPersonalItemList(list) {
        let models = [];
        if (HLLUTools.isArray(list)) {
            list.forEach(item => {
                let model = this.createPersonalListItem(item);
                if (model) {
                    models.push(model);
                }
            });
        }
        return models;
    }
}

class HLLUAccountBenefitsModel {
    constructor() {
        this.action_link = "";
        this.background_img_url = "";
        this.button_text = "";
        this.desc = "";
        this.premium_code = "";
        this.premium_icon_url = "";
        this.premium_name = "";
        this.premium_id = 0;
        this.premium_status = 0;
        this.premium_type = 0;
    }
    static createAccountBenefitsModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { action_link, background_img_url, button_text, desc, premium_code, premium_icon_url, premium_name, premium_id, premium_status, premium_type } = info;
            model.action_link = HLLUTools.$string(action_link);
            model.background_img_url = HLLUTools.$string(background_img_url);
            model.button_text = HLLUTools.$string(button_text);
            model.desc = HLLUTools.$string(desc);
            model.premium_code = HLLUTools.$string(premium_code);
            model.premium_icon_url = HLLUTools.$string(premium_icon_url);
            model.premium_name = HLLUTools.$string(premium_name);
            model.premium_id = HLLUTools.$number(premium_id);
            model.premium_status = HLLUTools.$number(premium_status);
            model.premium_type = HLLUTools.$number(premium_type);
        }
        return model;
    }
}

// 导航高度
// 个人中心接口数据缓存
const kPersonCenterAdReqeustDataCache = 'kPersonCenterAdReqeustDataCache';
// 固定栏模块
const kPinsKeyWord = 'pins';
const kBannerKeyWord = 'banner';
const kServersKetWord = 'services';
// 角标点击标识前缀
const kCornerClickPreFlag = 'kCornerClickPreFlag';
// 信用评价存储标识前缀
const kCreditFlag = 'kCreditFlag';
// 是否进入过订单共享的标识
const kHasEnterOrderShareFlag = 'kHasEnterOrderShareFlag';
// 监听刷新页面的通知
const kRefreshPageNotification = 'kRefreshPageNotification';

class HLLUElementItemView extends paladin$1.View {
    constructor() {
        super(...arguments);
        this.model = new HLLUPersonalListItemModel();
        this.index = 0;
        this.moduleName = "";
        this.allModel = new HLLUModuleConfigModel();
        /// 角标，给引导用的
        this.subArrowView = null;
        this.islogin = false;
        this.isGuide = false;
    }
    static createElementItemView(model, size, index, moduleName, islogin, isGuide) {
        let view = new this;
        view.size = size;
        view.model = model;
        view.index = index;
        view.moduleName = moduleName;
        view.islogin = islogin;
        if (isGuide != null && isGuide == true) {
            view.isGuide = true;
        }
        view.layout();
        view.onClick = () => {
            if (view.clickItemCallBack) {
                view.clickItemCallBack();
            }
            view.clickAction();
        };
        return view;
    }
    clickAction() {
        let { isAll, ads_exposure_url, ads_hit_url, ads_log_commonparam, corner_click_show, cornerType, corner_bottom_title, profile_credit_info, action_link, last_order_time, ad_id, _su } = this.model;
        if (corner_click_show == 1) {
            store(kCornerClickPreFlag + this.model.ad_id, "" + new Date().getTime());
        }
        publish(kRefreshPageNotification);
        if (cornerType == HLLUCornerType.RedSpot) {
            store(kCornerClickPreFlag + this.model.ad_id, "" + new Date().getTime());
            this.model.red_mark = 0;
            if (corner_bottom_title == "客户管理") {
                // 客户管理小红点已读上报
                HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserToken, {}, (info) => {
                    if (HLLUTools.isObject(info)) {
                        let { token } = info;
                        let item = {
                            method: HLLUMethod.customSetReadDot,
                            params: {
                                token
                            }
                        };
                        fetch(item);
                    }
                });
            }
        }
        if (cornerType == HLLUCornerType.Text && corner_bottom_title == "信用评价") {
            let closeTime = new Date().getTime();
            let dataVersion = profile_credit_info.data_version;
            HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserFid, {}, (info) => {
                if (HLLUTools.isObject(info)) {
                    let { user_fid } = info;
                    let userFid = HLLUTools.$string(user_fid);
                    if (userFid.length > 0) {
                        let dataVersionInfo = {
                            closeTime,
                            dataVersion
                        };
                        store(kCreditFlag + userFid, JSON.stringify(dataVersionInfo));
                    }
                }
            });
        }
        if (action_link == 'share_order') {
            store(kHasEnterOrderShareFlag, "1");
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.setLastEnterShareOrderTimestamp, {
                'last_order_timestamp': last_order_time
            });
        }
        // 点击上报神策，只报新的埋点
        HLLUBridge.sendTrackSensorEvent({
            name: "personal_center_NEW",
            properties: {
                event_type: "点击",
                frame_city: HLLUTools.getFrameCity(),
                button_type: corner_bottom_title,
                module_type: this.moduleName
            }
        });
        // 点击上报广告
        if (!isAll) {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.reportAdvertiseSensor, {
                url: ads_hit_url,
                parameter: ads_log_commonparam,
                adIds: {}
            });
            if (corner_bottom_title == '余额') {
                if (this.islogin) {
                    HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.openWalletyPageEvent);
                }
                else {
                    HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.openLoginPageEvent);
                }
            }
            else if (corner_bottom_title == '优惠券') {
                if (this.islogin) {
                    HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.openCouponPageEvent);
                }
                else {
                    HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.openLoginPageEvent);
                }
            }
            else if (corner_bottom_title == '地址上报' && PLDEnvironment.platform.toLowerCase() == 'ios') {
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.openAddressUploadPageEvent);
            }
            else {
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickPersonalEntranceCommonEvent, this.model);
            }
        }
        else {
            // 跳转更多服务
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.openMoreServicePageEvent, {
                title: '全部服务',
                more_data: this.allModel
            });
        }
    }
    layout() {
        let imageView = this.createHeaderAvatarImageView();
        imageView.centerX = this.centerX;
        if (this.isGuide == true) {
            imageView.y = 3;
        }
        this.addSubView(imageView);
        let titleLabel = this.createTitleLabel();
        titleLabel.centerX = this.centerX;
        titleLabel.top = imageView.bottom + 2;
        this.addSubView(titleLabel);
        // 曝光上报神策，只报新的埋点
        let { corner_bottom_title, ads_exposure_url, ads_log_commonparam } = this.model;
        HLLUBridge.sendTrackSensorEvent({
            name: "personal_center_NEW",
            properties: {
                event_type: "曝光",
                frame_city: HLLUTools.getFrameCity(),
                button_type: corner_bottom_title,
                module_type: this.moduleName
            },
            needControl: true
        });
    }
    createHeaderAvatarImageView() {
        let imageView = new paladin$1.ImageView;
        if (this.model.isAll) {
            imageView.image = HLLUImageNames.ic_personal_more_adv;
            imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        }
        else {
            imageView.imageUrl = this.model.content;
        }
        imageView.width = 28;
        imageView.height = 28;
        return imageView;
    }
    createTitleLabel() {
        let label = HLLUIHelper.createLabel(this.generateFitableTitle(this.model.corner_bottom_title), HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p85), HLLUFont.fontWithParams(12));
        label.sizeToFit();
        label.height = 18;
        return label;
    }
    generateFitableTitle(title) {
        if (title.length == 5) {
            return title;
        }
        if (title.length > 4) {
            title = title.substring(0, 4) + "...";
        }
        return title;
    }
}

class HLLUCornerView extends paladin.View {
    constructor() {
        super(...arguments);
        this.model = new HLLUPersonalListItemModel;
    }
    static createCornerView() {
        let view = new this;
        return view;
    }
    layout() {
        if (this.model.cornerType === HLLUCornerType.Text) {
            let view = new paladin.View;
            view.borderColor = HLLUColorValue.white;
            view.borderWidth = 1;
            view.cornerRadius = 8;
            view.height = 17;
            view.backgroundColor = HLLUColorValue.themeColor;
            let titleLabel = this.createTitleLabel();
            view.width = titleLabel.width + 8;
            titleLabel.center = view.center;
            let leftImageView = this.createLeftImageView();
            leftImageView.centerY = view.centerY + 0.5;
            this.addSubView(view);
            view.addSubView(titleLabel);
            this.addSubView(leftImageView);
            this.width = view.width;
            this.height = view.height;
        }
        else if (this.model.cornerType === HLLUCornerType.RedSpot) {
            this.width = 8;
            this.height = 8;
            this.cornerRadius = 4;
            this.backgroundColor = HLLUColorValue.FF3B30;
        }
        else if (this.model.cornerType === HLLUCornerType.NumberSpot) {
            let { unreadMessageCount } = this.model;
            if (unreadMessageCount == 0) {
                return;
            }
            let finalNumStr = unreadMessageCount + '';
            if (unreadMessageCount > 99) {
                finalNumStr = "...";
            }
            this.width = 16;
            this.height = 16;
            this.cornerRadius = 8;
            this.backgroundColor = HLLUColorValue.FF3B30;
            this.borderColor = HLLUColorValue.white;
            this.borderWidth = 1;
            let label = HLLUIHelper.createLabel(`${finalNumStr}`, HLLUColorValue.white, HLLUFont.fontWithParams(10, HLLUFontWeight.Bold));
            label.sizeToFit();
            this.addSubView(label);
            label.center = this.center;
            if (unreadMessageCount > 99) {
                label.top = label.top - 3;
            }
        }
    }
    createTitleLabel() {
        let label = HLLUIHelper.createLabel(this.model.corner_text, HLLUColorValue.white, HLLUFont.fontWithParams(10, HLLUFontWeight.Bold));
        label.sizeToFit();
        return label;
    }
    createLeftImageView() {
        let imageView = new paladin.ImageView;
        imageView.image = HLLUImageNames.ic_person_corner_left;
        imageView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imageView.width = 8;
        imageView.height = 18;
        return imageView;
    }
}

class HLLUShareOrderDotModel {
    constructor() {
        this.red_num = 0;
        this.last_order_time = 0;
    }
    static createShareOrderDotModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { red_num, last_order_time } = info;
            model.red_num = HLLUTools.$number(red_num);
            model.last_order_time = HLLUTools.$number(last_order_time);
        }
        return model;
    }
}

class HLLUModuleBoxView extends paladin.View {
    constructor() {
        super(...arguments);
        this.shareOrderDotModel = new HLLUShareOrderDotModel();
        this.model = new HLLUModuleConfigModel();
        this.unreadMessageCount = 0;
        this.guideId = 0;
        this.guideView = null;
        this.guideCallBack = null;
        this.isLogin = false;
    }
    static createInformationView(width) {
        let view = new this;
        view.width = width;
        return view;
    }
    layout() {
        // 创建背景图
        let bgView = this.createBgView();
        this.addSubView(bgView);
        this.guideView = null;
        // 创建标题
        let titleLastView;
        if (this.model.keyword != kPinsKeyWord) {
            let titleLabel = this.createTitleLabel();
            bgView.addSubView(titleLabel);
            titleLastView = titleLabel;
        }
        let lastView;
        // 取数组的前11个元素
        let displayList = [...this.model.list];
        if (this.model.list.length > 12 && this.model.keyword == kServersKetWord) {
            displayList = [];
            for (let i = 0; i < 11; i++) {
                displayList.push(this.model.list[i]);
            }
            // 添加一个额外的模型
            let extraModel = new HLLUPersonalListItemModel;
            extraModel.isAll = true;
            extraModel.corner_bottom_title = "全部服务";
            displayList.push(extraModel);
        }
        // 创建广告位
        let rowCount = 4;
        if (this.model.keyword != kPinsKeyWord && this.model.keyword != kServersKetWord) {
            rowCount = 5;
        }
        let itemWidth = (this.width - 40) / rowCount;
        for (let i = 0; i < displayList.length; i++) {
            let item = displayList[i];
            let itemView = HLLUElementItemView.createElementItemView(item, { width: itemWidth, height: 48 }, i, this.model.name, this.isLogin);
            itemView.allModel = this.model;
            bgView.addSubView(itemView);
            let row = i % rowCount;
            if (row == 0) {
                itemView.left = 8;
            }
            else {
                itemView.left = lastView.right;
            }
            let col = Math.floor(i / rowCount);
            if (titleLastView) {
                itemView.top = titleLastView.bottom + 12 + col * (itemView.height + 20);
            }
            else {
                itemView.top = 16 + col * (itemView.height + 20);
            }
            lastView = itemView;
            this.configCornerType(item);
            if (item.ad_id == this.guideId.toString()) {
                if (this.guideCallBack) {
                    let guideFrame = itemView.frame;
                    guideFrame.x = itemView.x + bgView.x;
                    this.guideCallBack({ "item": item, "frame": guideFrame, "index": i, "moduleName": this.model.name });
                }
                this.guideCallBack = null;
            }
            // 开始处理角标处理展示 
            if (item.cornerType != HLLUCornerType.None) {
                let cornerTextView = HLLUCornerView.createCornerView();
                cornerTextView.model = item;
                cornerTextView.layout();
                if (item.cornerType == HLLUCornerType.Text) {
                    cornerTextView.left = itemView.width / 2 + itemView.left;
                    cornerTextView.top = itemView.top - 8;
                }
                else if (item.cornerType == HLLUCornerType.RedSpot) {
                    cornerTextView.left = itemView.left + itemView.width * 2 / 3;
                    cornerTextView.top = itemView.top - 8;
                }
                else if (item.cornerType == HLLUCornerType.NumberSpot) {
                    cornerTextView.left = itemView.width * 2 / 3 + itemView.left;
                    cornerTextView.top = itemView.top - 8;
                }
                bgView.addSubView(cornerTextView);
            }
        }
        if (lastView) {
            bgView.height = lastView.bottom + 14;
        }
        this.height = bgView.bottom;
    }
    configCornerType(item) {
        let { corner_click_show, red_mark, corner_text, ad_id, corner_top_right, corner_end_time, corner_start_time, profile_credit_info, corner_bottom_title } = item;
        let currentTime = new Date().getTime() / 1000;
        if (corner_click_show == 1 && ad_id.length > 0) {
            // 是否点击过
            let adIdFlag = retrieve(kCornerClickPreFlag + ad_id);
            if (adIdFlag) {
                item.hasBeenClicked = true;
            }
        }
        // 最终判断是否展示角标 
        item.shouldShowCorner = item.corner_top_right == 1 && currentTime <= corner_end_time && currentTime >= corner_start_time && !item.hasBeenClicked;
        if (item.shouldShowCorner) {
            item.cornerType = HLLUCornerType.Text;
        }
        if (corner_bottom_title == '信用评价') {
            let isShowCreditEvaluationCorner = profile_credit_info.has_contorl == 1 || profile_credit_info.has_warning == 1;
            let isNOLimit = this.isShowCreditEvaluationCorner(profile_credit_info.data_version);
            if (isShowCreditEvaluationCorner && isNOLimit) {
                item.corner_text = "请关注";
                item.cornerType = HLLUCornerType.Text;
            }
        }
        if (!item.shouldShowCorner && red_mark == 1) {
            item.shouldShowCorner = true;
            item.cornerType = HLLUCornerType.RedSpot;
        }
        if (item.hasBeenClicked) {
            item.cornerType = HLLUCornerType.None;
        }
        if (corner_bottom_title == '我的司机' || corner_bottom_title == '收藏司机') {
            item.cornerType = HLLUCornerType.NumberSpot;
            item.unreadMessageCount = this.unreadMessageCount;
        }
        if (corner_bottom_title == '订单共享') {
            this.setShareOrderCorner(item);
        }
    }
    setShareOrderCorner(item) {
        item.cornerType = HLLUCornerType.None;
        let hasEnter = retrieve(kHasEnterOrderShareFlag);
        if (!hasEnter) {
            item.corner_text = "New";
            item.cornerType = HLLUCornerType.Text;
            return;
        }
        item.cornerType = HLLUCornerType.NumberSpot;
        HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.getLastEnterShareOrderTimestamp, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { last_order_timestamp } = info;
                last_order_timestamp = HLLUTools.$number(last_order_timestamp);
                let { red_num, last_order_time } = this.shareOrderDotModel;
                item.last_order_time = last_order_time;
                item.shareOrderLastTimeStamp = last_order_time;
                if (red_num > 0) {
                    // 展示数字角标
                    item.cornerType = HLLUCornerType.NumberSpot;
                    item.unreadMessageCount = red_num;
                }
                else if (last_order_time > last_order_timestamp) {
                    // 展示红点角标
                    item.cornerType = HLLUCornerType.RedSpot;
                }
            }
        });
    }
    isShowCreditEvaluationCorner(currentDataVersion) {
        let userFid = "";
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getUserFid, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { user_fid } = info;
                userFid = HLLUTools.$string(user_fid);
            }
        });
        if (userFid.length > 0) {
            let creditEvaluationInfoString = retrieve(kCreditFlag + userFid);
            if (creditEvaluationInfoString.length > 0) {
                let creditCacheDic = JSON.parse(creditEvaluationInfoString);
                if (HLLUTools.isObject(creditCacheDic)) {
                    let { closeTime, dataVersion } = creditCacheDic;
                    if (closeTime <= 0) {
                        return true;
                    }
                    let nowTime = new Date().getTime();
                    if (nowTime < closeTime) {
                        return true;
                    }
                    // 距离上一次点击关闭角标是否超过了七天 如果超过七天有数据便展示且清除上次关闭时间 没有超过不展示
                    let timeDifferenceValue = (nowTime - closeTime) / 60 / 60 / 24;
                    let isConformLimit = timeDifferenceValue > 7;
                    let isDataVersionLimit = currentDataVersion == dataVersion;
                    if (isConformLimit) {
                        //距离上次点击关闭角标超过七天 清除上次关闭时间
                        remove(kCreditFlag + userFid);
                    }
                    return isConformLimit && isDataVersionLimit;
                }
            }
        }
        return false;
    }
    createTitleLabel() {
        let label = HLLUIHelper.createLabel(this.model.name, HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p85), HLLUFont.fontWithParams(16, HLLUFontWeight.Bold, HLLUFontStyle.bold));
        label.left = 12;
        label.top = 12;
        label.lineHeight = 22;
        label.sizeToFit();
        return label;
    }
    createBgView() {
        let bgView = new paladin.View;
        bgView.left = 12;
        bgView.width = this.width - 24;
        bgView.cornerRadius = 12;
        bgView.backgroundColor = HLLUColorValue.white;
        return bgView;
    }
}

class HLLUPageControlView extends paladin$1.View {
    constructor() {
        super();
        this.currentIndex = 0;
        this.count = 0;
    }
    static createPageControlView(currentIndex, count) {
        let view = new this;
        view.currentIndex = currentIndex;
        view.count = count;
        view.height = 3;
        return view;
    }
    layout() {
        let lastView;
        for (let i = 0; i < this.count; i++) {
            let spot = new paladin$1.View;
            spot.height = 3;
            if (i == this.currentIndex) {
                spot.width = 6;
                spot.backgroundColor = HLLUColorValue.themeColor;
            }
            else {
                spot.width = 3;
                spot.backgroundColor = HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p12);
            }
            spot.cornerRadius = 1.5;
            if (lastView) {
                spot.left = lastView.right + 4;
            }
            else {
                spot.left = 0;
            }
            this.addSubView(spot);
            lastView = spot;
        }
        if (lastView) {
            this.width = lastView.right;
        }
    }
}

class HLLUScrollBannerView extends paladin.View {
    constructor() {
        super(...arguments);
        this.currentBannerIndex = 0;
        this.model = new HLLUModuleConfigModel();
    }
    static createBannerView(width, model, index) {
        let view = new this;
        view.width = width;
        view.height = width * 0.234;
        view.model = model;
        view.currentBannerIndex = index;
        view.layout();
        return view;
    }
    layout() {
        if (this.model.list.length == 1) {
            this.createOneImageView();
            return;
        }
        const pagerView = paladin.ViewPager.viewWithFrame(12, 0, this.width - 24, this.height);
        pagerView.cornerRadius = 12;
        pagerView.autoPlay = true;
        pagerView.direction = 0 /* ViewPagerDirection.horizontal */;
        pagerView.circularScrollEnable = true;
        pagerView.pageViews = this.getTitlePagerViews();
        pagerView.autoPlayTimeInteval = 2;
        if (PLDEnvironment.platform.toLowerCase() != 'ios') {
            pagerView.pageIndex = this.currentBannerIndex;
        }
        pagerView.onPageChanged = (params) => {
            if (PLDEnvironment.platform.toLowerCase() != 'ios') {
                return;
            }
            if (this.pageChangedEvent) {
                this.pageChangedEvent(params.pageIndex);
            }
            let currentItem = this.model.list[params.pageIndex];
            let { ads_exposure_url, ads_log_commonparam, _su, corner_bottom_title, ad_id } = currentItem;
            let frame_city = HLLUTools.getFrameCity();
            // 曝光上报神策新事件
            HLLUBridge.sendTrackSensorEvent({
                name: "personal_center_NEW",
                properties: {
                    event_type: "曝光",
                    frame_city,
                    button_type: corner_bottom_title,
                    module_type: this.model.name
                },
                needControl: true
            });
            // 曝光上报神策旧事件
            HLLUBridge.sendTrackSensorEvent({
                name: "advertise_resource_position",
                properties: {
                    ad_id,
                    ad_title: corner_bottom_title,
                    advertise_type: "个人中心banner",
                    _su,
                    event_type: "曝光"
                },
                needControl: true
            });
            // 曝光上报广告
            let hasSensored = HLLUSensorControl.getInstance().sensorDict[ads_log_commonparam + ads_exposure_url];
            if (!hasSensored) {
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.reportAdvertiseSensor, {
                    url: ads_exposure_url,
                    parameter: ads_log_commonparam,
                    adIds: {}
                });
                HLLUSensorControl.getInstance().sensorDict[ads_log_commonparam + ads_exposure_url] = true;
            }
        };
        pagerView.onPageFinished = (params) => {
            if (this.pageChangedEvent) {
                this.pageChangedEvent(params.pageIndex);
            }
        };
        this.addSubView(pagerView);
        // 创建分页器
        let pageControlView = HLLUPageControlView.createPageControlView(0, pagerView.pageViews.length);
        pageControlView.bottom = pagerView.bottom - 8;
        pageControlView.currentIndex = this.currentBannerIndex;
        pageControlView.layout();
        pageControlView.centerX = this.centerX;
        this.addSubView(pageControlView);
    }
    createOneImageView() {
        let model = this.model.list[0];
        const view = paladin.View.viewWithFrame(12, 0, this.width - 24, this.height);
        view.onClick = () => {
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickPersonalEntranceCommonEvent, model);
            publish(kRefreshPageNotification);
            let { corner_bottom_title, ad_id, _su, ads_hit_url, ads_log_commonparam } = model;
            let frame_city = HLLUTools.getFrameCity();
            // 点击上报神策新事件
            HLLUBridge.sendTrackSensorEvent({
                name: "personal_center_NEW",
                properties: {
                    event_type: "点击",
                    frame_city,
                    button_type: corner_bottom_title,
                    module_type: this.model.name
                }
            });
            // 点击上报神策旧事件
            HLLUBridge.sendTrackSensorEvent({
                name: "advertise_resource_position",
                properties: {
                    ad_id,
                    ad_title: corner_bottom_title,
                    advertise_type: "个人中心banner",
                    _su,
                    event_type: "点击"
                }
            });
            // 点击上报广告
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.reportAdvertiseSensor, {
                url: ads_hit_url,
                parameter: ads_log_commonparam,
                adIds: {}
            });
        };
        view.cornerRadius = 12;
        view.backgroundColor = HLLUColorValue.white;
        let imageView = new paladin.ImageView;
        imageView.imageUrl = model.content;
        imageView.width = view.width;
        imageView.height = view.height;
        view.addSubView(imageView);
        this.addSubView(view);
    }
    getTitlePagerViews() {
        var views = [];
        for (var index = 0; index < this.model.list.length; index++) {
            let model = this.model.list[index];
            const view = paladin.View.viewWithFrame(0, 0, this.width - 24, this.height);
            view.onClick = () => {
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickPersonalEntranceCommonEvent, model);
                publish(kRefreshPageNotification);
                let { corner_bottom_title, ad_id, _su, ads_hit_url, ads_log_commonparam } = model;
                let frame_city = HLLUTools.getFrameCity();
                // 点击上报神策新事件
                HLLUBridge.sendTrackSensorEvent({
                    name: "personal_center_NEW",
                    properties: {
                        event_type: "点击",
                        frame_city,
                        button_type: corner_bottom_title,
                        module_type: this.model.name
                    }
                });
                // 点击上报神策旧事件
                HLLUBridge.sendTrackSensorEvent({
                    name: "advertise_resource_position",
                    properties: {
                        ad_id,
                        ad_title: corner_bottom_title,
                        advertise_type: "个人中心banner",
                        _su,
                        event_type: "点击"
                    }
                });
                // 点击上报广告
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.reportAdvertiseSensor, {
                    url: ads_hit_url,
                    parameter: ads_log_commonparam,
                    adIds: {}
                });
            };
            view.cornerRadius = 12;
            view.backgroundColor = HLLUColorValue.white;
            let imageView = new paladin.ImageView;
            imageView.imageUrl = model.content;
            imageView.width = view.width;
            imageView.height = view.height;
            imageView.cornerRadius = 12;
            view.addSubView(imageView);
            views.push(view);
        }
        return views;
    }
}

class HLLUGuidePopModel {
    constructor() {
        this.business_guide_id = 0;
        this.pic_link = "";
        this.times_type = 0;
    }
    static createGuidePopModel(info) {
        let model = new this;
        if (HLLUTools.isObject(info)) {
            let { business_guide_id, pic_link, times_type } = info;
            model.business_guide_id = HLLUTools.$number(business_guide_id);
            model.times_type = HLLUTools.$number(times_type);
            model.pic_link = HLLUTools.$string(pic_link);
        }
        return model;
    }
}

class HLLUContainerModuleView extends paladin.View {
    constructor() {
        super();
        this.list = [];
        this.currentBannerIndex = 0;
        this.unreadMessageCount = 0;
        this.shareOrderDotModel = new HLLUShareOrderDotModel();
        this.guideModel = new HLLUGuidePopModel();
        this.guideCallBack = null;
        this.islogin = false;
    }
    static createContainerModuleView(width) {
        let view = new this;
        view.width = width;
        return view;
    }
    layout() {
        // 根据数组配置生成各模块
        let lastView;
        for (let i = 0; i < this.list.length; i++) {
            let item = this.list[i];
            let index = i;
            var bottomTop = 0;
            if (lastView) {
                bottomTop = lastView.bottom + 12;
            }
            let moduleView = this.createSubView(item, index, this.guideModel.business_guide_id, bottomTop);
            if (moduleView == null) {
                continue;
            }
            if (lastView) {
                moduleView.top = lastView.bottom + 12;
            }
            else {
                moduleView.top = 0;
            }
            this.addSubView(moduleView);
            lastView = moduleView;
        }
        this.height = lastView.bottom;
    }
    createSubView(item, index, guideId, bottom) {
        if (item.keyword == kBannerKeyWord) {
            if (item.list.length == 0) {
                return null;
            }
            let view = HLLUScrollBannerView.createBannerView(this.width, item, this.currentBannerIndex);
            view.pageChangedEvent = (value) => {
                if (this.pageChangedEvent) {
                    this.pageChangedEvent(value);
                }
            };
            return view;
        }
        else {
            let moduleView = HLLUModuleBoxView.createInformationView(this.width);
            moduleView.model = item;
            moduleView.guideId = guideId;
            moduleView.isLogin = this.islogin;
            moduleView.shareOrderDotModel = this.shareOrderDotModel;
            moduleView.unreadMessageCount = this.unreadMessageCount;
            moduleView.guideCallBack = (item) => {
                if (item["item"] != null && this.guideCallBack) {
                    let frame = item["frame"];
                    frame.x += moduleView.x;
                    frame.y += bottom;
                    this.guideCallBack({ "item": item["item"], "frame": frame, "index": item["item"], "moduleName": item["moduleName"] });
                }
                this.guideCallBack = null;
            };
            moduleView.layout();
            // 进行广告曝光
            let firstItem = new HLLUPersonalListItemModel();
            if (item.list.length > 0) {
                firstItem = item.list[0];
            }
            let showStringArray = [];
            let bottomTitleStringArray = [];
            let adMaterialStringArray = [];
            for (let i = 0; i < item.list.length; i++) {
                let model = item.list[i];
                showStringArray.push(model.ad_id);
                adMaterialStringArray.push(model.ad_material_id);
                bottomTitleStringArray.push(model.corner_bottom_title);
            }
            let showString = showStringArray.join("-");
            let showStringSensorsAnalytics = showStringArray.join(",");
            let adMaterialString = adMaterialStringArray.join("-");
            let bottomTitleString = bottomTitleStringArray.join(",");
            let adIds = {
                ides: showString,
                adMaterialId: adMaterialString
            };
            let hasSensored = HLLUSensorControl.getInstance().sensorDict[JSON.stringify(adIds)];
            if (!hasSensored) {
                HLLUSensorControl.getInstance().sensorDict[JSON.stringify(adIds)] = true;
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.reportAdvertiseSensor, {
                    url: firstItem.ads_exposure_url,
                    parameter: firstItem.ads_log_commonparam,
                    adIds
                });
            }
            // 将神策的也加上
            HLLUBridge.sendTrackSensorEvent({
                name: "advertise_resource_expo",
                properties: {
                    advertise_type: item.name,
                    ad_id_list: showStringSensorsAnalytics,
                    ad_title_list: bottomTitleString,
                    trigger_time: new Date().getTime() + "",
                    ad_city: HLLUTools.getFrameCity(),
                },
                needControl: true,
                specialSensor: JSON.stringify({
                    advertise_type: item.name,
                    ad_id_list: showStringSensorsAnalytics,
                    ad_title_list: bottomTitleString,
                    ad_city: HLLUTools.getFrameCity(),
                })
            });
            return moduleView;
        }
    }
}

class HLLUGuideView extends paladin.View {
    constructor() {
        super(...arguments);
        this.model = null;
        this.needShow = false;
        this.index = 0;
        this.guideFrame = { x: 0, y: 0, width: 0, height: 0 };
        this.itemModel = null;
        this.isLogin = false;
        this.modelName = "";
    }
    static createGuideView(model, modelName) {
        let view = new this;
        view.model = model;
        view.modelName = modelName;
        return view;
    }
    layout() {
        let guideBgView = new paladin.View;
        guideBgView.size = { width: 240, height: 80 };
        let guideView = HLLUElementItemView.createElementItemView(this.itemModel, { width: 58, height: 58 }, this.index, this.modelName, this.isLogin, true);
        guideView.frame = this.guideFrame;
        let bgView = new paladin.View;
        bgView.backgroundColor = HLLUColor.colorWithHex(HLLUColorValue.black, HLLUAlpha.p70);
        bgView.width = this.width;
        bgView.height = this.height;
        bgView.onClick = () => {
            if (this.dismissCallBack) {
                this.dismissCallBack({ "title": "蒙层关闭" });
            }
        };
        /// 位置微调
        let topPadding = 3;
        let guideCenter = guideView.center;
        let alphaView = this.creatAlphaView();
        alphaView.center = guideCenter;
        alphaView.y += topPadding;
        guideView.backgroundColor = HLLUColor.white;
        guideView.size = { width: 58, height: 58 };
        guideView.center = guideCenter;
        guideView.y += topPadding;
        guideView.clipToBounds = true;
        guideView.cornerRadius = 58 / 2;
        guideBgView.center = guideView.center;
        guideView.center = { x: guideBgView.width / 2, y: 40 };
        var cornerTextView = null;
        if (this.itemModel.cornerType != HLLUCornerType.None) {
            cornerTextView = HLLUCornerView.createCornerView();
            cornerTextView.model = this.itemModel;
            cornerTextView.layout();
            if (this.itemModel.cornerType == HLLUCornerType.Text) {
                cornerTextView.left = guideView.x + (guideView.width / 2);
                cornerTextView.top = 5;
            }
            else if (this.itemModel.cornerType == HLLUCornerType.RedSpot) {
                cornerTextView.left = guideView.x + (guideView.width * 2 / 3);
                cornerTextView.top = 5;
            }
            else if (this.itemModel.cornerType == HLLUCornerType.NumberSpot) {
                cornerTextView.left = guideView.x + (guideView.width * 2 / 3);
                cornerTextView.top = 5;
            }
        }
        let guideMaxY = guideBgView.bottom - 8;
        let lineImageView = this.creatLinewImageView();
        lineImageView.centerX = guideBgView.centerX;
        lineImageView.y = guideMaxY + 12;
        let imageView = this.creatGuideImage();
        imageView.y = lineImageView.y + lineImageView.height + 10;
        imageView.centerX = this.width / 2;
        imageView.onClick = () => {
            if (this.clickItemCallBack) {
                this.clickItemCallBack({ "title": "图片内容" });
            }
            guideView.clickAction();
        };
        let closeButton = this.creatCloseButton();
        var typeUp = false;
        let limitY = guideMaxY + 163;
        if (limitY > (this.height - 60)) {
            typeUp = true;
        }
        if (typeUp) {
            lineImageView.image = HLLUImageNames.ic_home_force_alert_line_up;
            lineImageView.y = guideBgView.y + 8 - 10 - 43;
            imageView.y = lineImageView.y - imageView.height - 20;
        }
        closeButton.x = imageView.right - closeButton.width;
        closeButton.y = imageView.y;
        guideView.clickItemCallBack = () => {
            if (this.clickItemCallBack) {
                this.clickItemCallBack({ "title": "高亮" });
            }
        };
        bgView.addSubView(alphaView);
        bgView.addSubView(guideBgView);
        guideBgView.addSubView(guideView);
        if (cornerTextView != null) {
            guideBgView.addSubView(cornerTextView);
        }
        bgView.addSubView(lineImageView);
        bgView.addSubView(imageView);
        bgView.addSubView(closeButton);
        if (guideView.bottom < this.height) {
            this.needShow = true;
        }
        this.addSubView(bgView);
    }
    creatAlphaView() {
        let alphaView = new paladin.View;
        alphaView.size = { width: 64, height: 64 };
        alphaView.alpha = 0.3;
        alphaView.backgroundColor = HLLUColor.white;
        alphaView.cornerRadius = 64 / 2;
        return alphaView;
    }
    creatGuideImage() {
        let guideView = new paladin.ImageView;
        let imageWidth = this.width - 40;
        let aspectRatio = 98 / 335;
        let imageViewHeight = imageWidth * aspectRatio;
        guideView.size = { width: imageWidth, height: imageViewHeight };
        guideView.cornerRadius = 20;
        if (this.model != null && this.model.pic_link != null && this.model.pic_link.length > 0) {
            guideView.imageUrl = this.model.pic_link;
        }
        return guideView;
    }
    creatCloseButton() {
        let close = new paladin.Button;
        close.size = { width: 54, height: 54 };
        close.onClick = () => {
            if (this.dismissCallBack) {
                this.dismissCallBack({ "title": "x关闭" });
            }
        };
        return close;
    }
    checkNeedShow(offset) {
        let maxY = offset + this.height;
        let guideMaxY = this.guideFrame.y + this.guideFrame.height;
        if (guideMaxY > maxY || this.guideFrame.y < offset) {
            this.needShow = false;
            return;
        }
        this.needShow = true;
    }
    creatLinewImageView() {
        let imgView = new paladin.ImageView;
        imgView.image = HLLUImageNames.ic_home_force_alert_line;
        imgView.bundle = bundlePath(HLLUImageBundle.path, HLLUImageBundle.name);
        imgView.size = { width: 16, height: 43 };
        return imgView;
    }
}

class HLLUPersonalCenterVc extends paladin.VC {
    constructor() {
        super(...arguments);
        // 订单共享入口红点模型数据
        this.shareOrderEntranceRedDotModel = new HLLUShareOrderDotModel;
        // 收藏司机的未读消息数
        this.unreadMessageCount = 0;
        // 当前选中的轮播图索引
        this.currentBannerIndex = 0;
        // 轮播图数据
        // 获取端智能AR的名称
        this.arName = '拍货选车';
        // 是否展示完整个人信息模块
        this.showLargeInformation = true;
        // 是否登录
        this.isLogined = 0;
        // 展示设置按钮的红点
        this.showSettingRedDot = false;
        // 是否展示扫码弹窗
        this.showScanPopView = false;
        this.popViewLocation = { x: 0, y: 0 };
        // 专业账户权益模型
        this.accountBenefitsModel = new HLLUAccountBenefitsModel();
        this.moduleConfigList = [];
        this.guidePopConfigList = [];
        this.isRequestGuide = false;
        this.uiParams = {
            is_support_ar_scan: 0,
            tabbar_height: 0
        };
        // 数据模型
        this.userInfoModel = new HLLUUserInfoModel();
    }
    onDisappear() {
        if (this.guidePopConfigList && this.guidePopConfigList.length > 0) {
            this.guidePopConfigList.shift();
            this.needLayout();
        }
    }
    onAppear() {
        // 请求个人中心业务数据
        if (this.showScanPopView) {
            this.showScanPopView = false;
            this.needLayout();
        }
        this.startMouldeRequest(true);
        // 判断是否需要展示设置小红点
        HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.checkIfShowSettingRedDot, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { show_setting_reddot } = info;
                this.showSettingRedDot = show_setting_reddot == 1;
                this.needLayout();
            }
        });
    }
    onLoad() {
        HLLUTools.getDeviceInfo((info) => {
            this.uiParams = info;
            this.needLayout();
        });
        // 设置通知监听
        this.configBroadcast();
        HLLUBridge.sendNavigatorNativeEvent(HLLUNavigatorEventBridge.setBarHidden, {
            hidden: true
        });
        // 获取MDAP配置
        this.getMDAPConfig();
        // 获取登录状态判断是否请求个人信息
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getLoginInfo, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { login_state, user_info } = info;
                this.isLogined = HLLUTools.$number(login_state);
                if (login_state == 1) {
                    // 先获取到用户信息刷新登录状态
                    this.isLogined = 1;
                    this.userInfoModel = HLLUUserInfoModel.createDriverInfoModel(user_info);
                    this.needLayout();
                    // 同时去请求个人信息数据
                    this.requestUserInfoData();
                }
            }
        });
        // 判断是否需要展示设置小红点
        HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.checkIfShowSettingRedDot, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { show_setting_reddot } = info;
                this.showSettingRedDot = show_setting_reddot == 1;
            }
        });
    }
    getMDAPConfig() {
        let mdap_key = "hll_arscan_config";
        if (PLDEnvironment.platform.toLowerCase() == 'ios') {
            mdap_key = "ar_page_name";
        }
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getMDAPConfigForStringValue, {
            mdap_key,
            default_value: "拍货选车"
        }, (info) => {
            if (HLLUTools.isObject(info)) {
                let mdapString = HLLUTools.$string(info.mdap_string);
                if (mdapString.length > 0) {
                    this.arName = mdapString;
                }
            }
        });
    }
    startMouldeRequest(isOnAppear) {
        this.requestPersonalCenterData();
        this.getUnreadMessageCount();
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getLoginInfo, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { login_state } = info;
                this.isLogined = HLLUTools.$number(login_state);
                if (login_state == 1) {
                    if (this.isRequestGuide == false && isOnAppear == true) {
                        this.isRequestGuide = true;
                        this.getGuidePopData();
                    }
                    this.getShareOrderBadgeData();
                    this.requestUserInfoData();
                }
            }
        });
    }
    // 获取共享订单角标数据
    getShareOrderBadgeData() {
        let item = {
            method: HLLUMethod.getShareOrderEntranceRedDot,
            params: {},
        };
        fetch(item, (result) => {
            this.shareOrderEntranceRedDotModel = HLLUShareOrderDotModel.createShareOrderDotModel(result);
            this.needLayout();
        });
    }
    // 获取未读数
    getUnreadMessageCount() {
        // 获取IM消息未读数 
        HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.getUnreadMessageCount, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { unread_count } = info;
                this.unreadMessageCount = unread_count;
                this.needLayout();
            }
        });
    }
    // 请求个人中心业务数据
    requestPersonalCenterData() {
        let is_support_ar_scan = this.uiParams.is_support_ar_scan;
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getCityInfo, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { city_id } = info;
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.getRecommendSwitch, {}, (info) => {
                    if (HLLUTools.isObject(info)) {
                        let { recommend_switch } = info;
                        let is_close_recomment = 1;
                        if (this.isLogined == 1) {
                            is_close_recomment = recommend_switch == 1 ? 0 : 1;
                        }
                        let item = {
                            method: HLLUMethod.personalCenter,
                            params: {
                                city_id,
                                is_close_recomment,
                                is_support_ar_scan
                            }
                        };
                        // 先判断是否存在缓存
                        let serverCacheData = retrieve(kPersonCenterAdReqeustDataCache);
                        let isCacheExit = false;
                        if (serverCacheData && serverCacheData.length > 0) {
                            // 缓存存在，直接解析数据
                            isCacheExit = true;
                            let result = JSON.parse(serverCacheData);
                            this.parserPersonalCenterData(result);
                        }
                        if (!isCacheExit) {
                            publish(HLLUBroadCastEvent.showLoadingLottieAniamtion);
                        }
                        requestPersonalCenterDataInMock(item, (result) => {
                            if (!isCacheExit) {
                                publish(HLLUBroadCastEvent.hideLoadingLottieAniamtion);
                            }
                            paladin.loge('sssss', result);
                            this.parserPersonalCenterData(result, true);
                        });
                    }
                });
            }
        });
    }
    // 获取引导弹窗数据
    getGuidePopData() {
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getCityInfo, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { city_id } = info;
                let item = {
                    method: HLLUMethod.personalCenterGuidePop,
                    params: {
                        city_id,
                    }
                };
                fetch(item, (result) => {
                    let { list } = result;
                    if (HLLUTools.isArray(list)) {
                        for (let i = 0; i < list.length; i++) {
                            let configModel = HLLUGuidePopModel.createGuidePopModel(list[i]);
                            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.getGuideCanShow, { "business_guide_id": configModel.business_guide_id, "times_type": configModel.times_type }, (info) => {
                                if (HLLUTools.isObject(info)) {
                                    let { can_show } = info;
                                    if (can_show == true && this.guidePopConfigList.length == 0) {
                                        this.guidePopConfigList.push(configModel);
                                    }
                                }
                            });
                        }
                    }
                    this.needLayout();
                });
            }
        });
    }
    parserPersonalCenterData(result, fromServer = false) {
        if (HLLUTools.isObject(result)) {
            if (fromServer) {
                // 写入缓存
                store(kPersonCenterAdReqeustDataCache, JSON.stringify(result));
            }
            let { module_config, account_benefits } = result;
            this.accountBenefitsModel = HLLUAccountBenefitsModel.createAccountBenefitsModel(account_benefits);
            // 接续module_config数据
            if (HLLUTools.isArray(module_config)) {
                this.moduleConfigList = [];
                for (let i = 0; i < module_config.length; i++) {
                    let configModel = HLLUModuleConfigModel.createModuleConfigModel(module_config[i]);
                    // 继续获取对应模块的数据
                    let list = result[configModel.keyword];
                    configModel.list = HLLUPersonalListItemModel.createPersonalItemList(list);
                    this.moduleConfigList.push(configModel);
                }
            }
            this.needLayout();
        }
    }
    configBroadcast() {
        // 监听登录通知
        subscribe(HLLUBroadCastEvent.kNotificationLogin, () => {
            // 开始请求个人信息数据
            this.startMouldeRequest(false);
        });
        // 监听退出登录通知 
        subscribe(HLLUBroadCastEvent.kNotificationLogout, () => {
            // 退出登录
            this.isLogined = 0;
            this.needLayout();
            this.startMouldeRequest(false);
        });
        // 监听昵称修改通知
        subscribe(HLLUBroadCastEvent.kNotificationChangeUserNickName, () => {
            setTimeout(() => {
                this.requestUserInfoData();
            }, 1000);
        });
        // 监听刷新页面的通知
        subscribe(kRefreshPageNotification, () => {
            setTimeout(() => {
                paladin.loge('监听到了刷新');
                this.needLayout();
            }, 100);
        });
        subscribe(HLLUBroadCastEvent.kRefreshSettingRetDot, () => {
            setTimeout(() => {
                // 判断是否需要展示设置小红点
                HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.checkIfShowSettingRedDot, {}, (info) => {
                    if (HLLUTools.isObject(info)) {
                        let { show_setting_reddot } = info;
                        this.showSettingRedDot = show_setting_reddot == 1;
                    }
                });
            }, 100);
        });
    }
    requestUserInfoData() {
        if (this.isLogined != 1) {
            return;
        }
        HLLUBridge.collectUserBaseInfo(HLLUUserBaseInfoBridge.getCityInfo, {}, (info) => {
            if (HLLUTools.isObject(info)) {
                let { city_id } = info;
                let item = {
                    method: HLLUMethod.getUserInfo,
                    params: {
                        city_id
                    }
                };
                fetch(item, (result) => {
                    this.userInfoModel = HLLUUserInfoModel.createDriverInfoModel(result);
                    // 同步个人信息数据给端上
                    HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.sendUserInfoData, result);
                    this.isLogined = 1;
                    this.needLayout();
                });
            }
        });
    }
    layout() {
        const bgView = paladin.View.viewWithFrame(0, 0, this.width, this.height);
        // 创建滚动底图
        let bgScrollView = this.createBgScrollView();
        bgView.addSubView(bgScrollView);
        // 个人信息模块 
        let largeInformationView = this.createLargeInformatioView();
        largeInformationView.top = 0;
        largeInformationView.hidden = !this.showLargeInformation;
        bgScrollView.addSubView(largeInformationView);
        let smallInformationView = this.createSmallInformationView();
        smallInformationView.hidden = this.showLargeInformation;
        bgView.addSubView(smallInformationView);
        // 扫码弹窗
        if (this.showScanPopView) {
            let popView = HLLUPopverView.createPopverView({
                titles: ['扫一扫', this.arName],
                imageNames: [HLLUImageNames.ic_qr_entry, HLLUImageNames.ic_ar_scan_entry],
                clickEvent: (index) => {
                    // 点击弹窗选项
                    if (index == 0) {
                        // 点击扫一扫
                        HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.openScanPageEvent);
                    }
                    else {
                        // 打开端智能
                        HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.openARPageEvent);
                    }
                }
            });
            popView.left = this.popViewLocation.x - 72;
            popView.top = this.popViewLocation.y + 28;
            bgView.addSubView(popView);
        }
        // 费用信息模块
        if (this.moduleConfigList.length > 0) {
            let moduleView = this.createContainerModuleView(largeInformationView.bottom, bgScrollView, bgView);
            moduleView.height = moduleView.height + 24;
            bgScrollView.addSubView(moduleView);
        }
        return bgView;
    }
    createContainerModuleView(top, scrollView, superView) {
        let view = HLLUContainerModuleView.createContainerModuleView(this.width);
        view.list = this.moduleConfigList;
        if (this.guidePopConfigList.length > 0) {
            view.guideModel = this.guidePopConfigList[0];
        }
        view.islogin = this.isLogined == 1;
        view.shareOrderDotModel = this.shareOrderEntranceRedDotModel;
        view.unreadMessageCount = this.unreadMessageCount;
        view.currentBannerIndex = this.currentBannerIndex;
        view.top = top;
        view.left = 0;
        view.guideCallBack = (item) => {
            if (item["item"] != null) {
                let frame = item["frame"];
                frame.y += (top - 0);
                let businessIdStr = "";
                let itemModel = item["item"];
                let index = item["index"];
                let guideModel = this.guidePopConfigList[0];
                if (guideModel.business_guide_id != null) {
                    businessIdStr = guideModel.business_guide_id.toString();
                }
                let guideView = this.creatGuideView(guideModel, itemModel, frame, item["moduleName"], index, 0);
                if (guideView.needShow) {
                    HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.saveGuideShowTime, guideModel);
                    HLLUBridge.sendTrackSensorEvent({
                        name: "homepage_guide_expo",
                        properties: {
                            business_position: "个人中心",
                            business_id: businessIdStr,
                        },
                        needControl: true
                    });
                    superView.addSubView(guideView);
                }
            }
        };
        view.layout();
        view.pageChangedEvent = (index) => {
            this.currentBannerIndex = index;
            this.needLayout();
        };
        return view;
    }
    createSmallInformationView() {
        let view = HLLUInformationSmallView.createInformationView({ width: this.width, height: 44 + this.uiParams.tabbar_height });
        view.isLogined = this.isLogined == 1;
        view.userInfoModel = this.userInfoModel;
        view.showSettingRedDot = this.showSettingRedDot;
        view.layout(this.uiParams.tabbar_height);
        view.clickSettingEvent = () => {
            // 点击设置按钮 
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickSettingEvent, this.accountBenefitsModel);
            this.showSettingRedDot = false;
            this.needLayout();
        };
        view.clickScanEvent = (location) => {
            // 点击扫码按钮
            this.didClickScanEvent(location);
        };
        return view;
    }
    createLargeInformatioView() {
        let view = HLLUInformationLargeView.createInformationView({ width: this.width, height: 84 + this.uiParams.tabbar_height });
        view.isLogined = this.isLogined == 1;
        view.userInfoModel = this.userInfoModel;
        view.showSettingRedDot = this.showSettingRedDot;
        view.layout(this.uiParams.tabbar_height);
        view.clickSettingEvent = () => {
            // 点击设置按钮
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.clickSettingEvent, this.accountBenefitsModel);
            this.showSettingRedDot = false;
            this.needLayout();
        };
        view.clickScanEvent = (location) => {
            // 点击扫码按钮
            this.didClickScanEvent(location);
        };
        return view;
    }
    didClickScanEvent(location) {
        this.popViewLocation = location;
        if (this.isLogined == 1) {
            let is_support_ar_scan = this.uiParams.is_support_ar_scan;
            if (is_support_ar_scan == 1) {
                // 支持AR端智能，需要弹窗
                this.showScanPopView = true;
                this.needLayout();
                HLLUBridge.sendTrackSensorEvent({
                    name: "personal_center_NEW",
                    properties: {
                        event_type: "点击",
                        frame_city: HLLUTools.getFrameCity(),
                        button_type: this.arName,
                        module_type: "个人信息区域"
                    }
                });
            }
            else {
                // 直接开启扫一扫
                HLLUBridge.sendTrackSensorEvent({
                    name: "personal_center_NEW",
                    properties: {
                        event_type: "点击",
                        frame_city: HLLUTools.getFrameCity(),
                        button_type: "扫一扫",
                        module_type: "个人信息区域"
                    }
                });
                HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.openScanPageEvent);
            }
        }
        else {
            HLLUBridge.sendTrackSensorEvent({
                name: "personal_center_NEW",
                properties: {
                    event_type: "点击",
                    frame_city: HLLUTools.getFrameCity(),
                    button_type: "扫一扫",
                    module_type: "个人信息区域"
                }
            });
            HLLUBridge.sendCommonNativeEvent(HLLUCommonEventBridge.openLoginPageEvent);
        }
    }
    createBgScrollView() {
        let view = new paladin.ScrollView;
        view.backgroundColor = HLLUColorValue.f3f4f5;
        view.left = 0;
        view.top = 0;
        view.width = this.width;
        view.height = this.height;
        view.onScroll = (value) => {
            if (this.showScanPopView) {
                this.showScanPopView = false;
                this.needLayout();
            }
            let { y } = value;
            if (y >= 24 && this.showLargeInformation) {
                // 展示缩小的个人信息模块
                this.showLargeInformation = false;
                this.needLayout();
                return;
            }
            if (y < 24 && !this.showLargeInformation) {
                // 展示放大的个人信息模块
                this.showLargeInformation = true;
                this.needLayout();
            }
        };
        return view;
    }
    creatGuideView(model, itemModel, frame, moduleName, index, offset) {
        let view = HLLUGuideView.createGuideView(model, moduleName);
        view.width = this.width;
        view.height = this.height;
        view.itemModel = itemModel;
        view.index = index;
        view.guideFrame = frame;
        view.isLogin = this.isLogined == 1;
        view.dismissCallBack = (info) => {
            if (this.guidePopConfigList.length > 0) {
                this.guidePopConfigList.shift();
            }
            paladin.loge("track--miss", info["title"]);
            HLLUBridge.sendTrackSensorEvent({
                name: "homepage_guide_click",
                properties: {
                    business_position: "个人中心",
                    guide_off: info["title"] ? info["title"] : "",
                }
            });
            this.needLayout();
        };
        view.clickItemCallBack = (info) => {
            paladin.loge("track--", info["title"]);
            HLLUBridge.sendPersonalCenterNativeEvent(HLLUPersonalCenterEventBridge.saveGuideShowTime, model);
            if (this.guidePopConfigList.length > 0) {
                this.guidePopConfigList.shift();
            }
            HLLUBridge.sendTrackSensorEvent({
                name: "homepage_guide_click",
                properties: {
                    business_position: "个人中心",
                    guide_off: info["title"] ? info["title"] : "",
                }
            });
            this.needLayout();
        };
        view.layout();
        view.checkNeedShow(offset);
        return view;
    }
}
Paladin.Page(HLLUPersonalCenterVc);
//# sourceMappingURL=hllu-personal-center-bundle.js.map
